@@ -1,5 +1,5 @@
 # Copyright (C) 2001-2003, The Perl Foundation.
-# $Id: /parrot/offline/config/auto/gcc.pm 4558 2007-03-17T23:22:37.823693Z coke  $
+# $Id: gcc.pm 18148 2007-04-11 21:03:52Z paultcochrane $
 
 =head1 NAME
 
@@ -53,7 +53,9 @@ sub runstep {
 
     my $major = $gnuc{__GNUC__};
     my $minor = $gnuc{__GNUC_MINOR__};
-    unless ( defined $major ) {
+    my $intel = $gnuc{__INTEL_COMPILER};
+
+    if ( defined $intel || !defined $major ) {
         print " (no) " if $verbose;
         $self->set_result('no');
         $conf->data->set( gccversion => undef );
