@@ -1,5 +1,5 @@
 # Copyright (C) 2001-2006, The Perl Foundation.
-# $Id: /parrot/offline/config/gen/makefiles.pm 4637 2007-03-20T01:26:24.230584Z coke  $
+# $Id: makefiles.pm 18148 2007-04-11 21:03:52Z paultcochrane $
 
 =head1 NAME
 
@@ -59,10 +59,18 @@ EOF
 sub makefiles {
     my ( $self, $conf ) = @_;
 
-    genfile( 'config/gen/makefiles/root.in'         => 'Makefile' );
+    genfile( 'config/gen/makefiles/root.in' => 'Makefile' );
+
+    genfile(
+        'config/gen/makefiles/ext.in' => 'ext/Makefile',
+        commentType                   => '#',
+        replace_slashes               => 1,
+        conditioned_lines             => 1
+    );
     genfile(
         'config/gen/makefiles/parrot_embed.in' => 'ext/Parrot-Embed/Makefile.PL',
-        replace_slashes                     => 1,
+        replace_slashes                        => 0,
+        conditioned_lines                      => 1
     );
 
     genfile( 'config/gen/makefiles/past.in'      => 'compilers/past/Makefile' );
@@ -71,6 +79,7 @@ sub makefiles {
     genfile( 'config/gen/makefiles/tge.in'       => 'compilers/tge/Makefile' );
     genfile( 'config/gen/makefiles/bcg.in'       => 'compilers/bcg/Makefile' );
     genfile( 'config/gen/makefiles/json.in'      => 'compilers/json/Makefile' );
+    genfile( 'config/gen/makefiles/pirc.in'      => 'compilers/pirc/Makefile' );
     genfile( 'config/gen/makefiles/dynpmc.in'    => 'src/dynpmc/Makefile' );
     genfile( 'config/gen/makefiles/dynoplibs.in' => 'src/dynoplibs/Makefile' );
     genfile( 'config/gen/makefiles/editor.in'    => 'editor/Makefile' );
@@ -87,11 +96,6 @@ sub makefiles {
         replace_slashes                        => 0,
         conditioned_lines                      => 1
     );
-    genfile(
-        'config/gen/makefiles/ext.in' => 'ext/Makefile',
-        commentType                   => '#',
-        replace_slashes               => 1
-    );
     genfile( 'config/gen/makefiles/parrot.pc.in' => 'parrot.pc' );
 
     if ( $conf->data->get('has_perldoc') ) {
