@@ -1,5 +1,5 @@
 # Copyright (C) 2001-2005, The Perl Foundation.
-# $Id: /parrot/offline/config/init/defaults.pm 4106 2007-02-20T20:51:15.139458Z coke  $
+# $Id: defaults.pm 17923 2007-04-01 09:28:08Z paultcochrane $
 
 =head1 NAME
 
@@ -175,7 +175,7 @@ sub runstep {
         PATCH   => $main::parrot_version[2],
         DEVEL   => ( -e 'DEVELOPING' ? '-devel' : '' ),
 
-        configdate => scalar localtime,
+        configdate => scalar gmtime() . " GMT",
         PQ         => "'",
         dquote     => "\\\"",
 
