@@ -1,8 +1,9 @@
-#! perl -w
+#! perl
 use strict;
+use warnings;
 
-for my $i (1 .. 100000) {
-	my $o = new Foo();
+for my $i ( 1 .. 100000 ) {
+    my $o = new Foo();
 }
 my $o = new Foo();
 print $o->[0], "\n";
@@ -10,7 +11,7 @@ print $o->[0], "\n";
 package Foo;
 
 sub new {
-    my $self = ref $_[0] ? ref shift : shift;
+    my $self = ref $_[0] ? ref shift: shift;
     return bless [ 10, 20 ], $self;
 }
 1;
