@@ -2,7 +2,7 @@
  * debug.h
  *
  * SVN Info
- *    $Id: /parrot/offline/include/parrot/debug.h 2097 2006-11-12T21:36:03.837249Z coke  $
+ *    $Id: debug.h 17859 2007-03-30 19:19:26Z paultcochrane $
  * Overview:
  *    Parrot debugger header files
  * History:
@@ -198,7 +198,7 @@ void PDB_next(Interp *interp, const char *command);
 void PDB_trace(Interp *interp, const char *command);
 
 void PDB_eval(Interp *interp, const char *command);
-struct PackFile * PDB_compile(Interp *, const char *);
+opcode_t * PDB_compile(Interp *, const char *);
 
 int PDB_extend_const_table(Interp *interp);
 
