@@ -1,7 +1,7 @@
 /* events.h
  *  Copyright (C) 2001-2003, The Perl Foundation.
  *  SVN Info
- *     $Id: /parrot/offline/include/parrot/events.h 1844 2006-11-07T21:18:52.294908Z coke  $
+ *     $Id: events.h 17952 2007-04-03 02:00:50Z chromatic $
  *  Overview:
  *     This api will handle parrot events
  *  Data Structure and Algorithms:
@@ -78,8 +78,8 @@ PARROT_API void Parrot_schedule_event(Parrot_Interp, parrot_event*);
 PARROT_API void Parrot_schedule_interp_event(Parrot_Interp, parrot_event*);
 PARROT_API void Parrot_schedule_interp_qentry(Parrot_Interp, struct QUEUE_ENTRY* entry);
 
-#define CHECK_EVENTS(i, n)  Parrot_do_check_events(i, n)
-#define HANDLE_EVENTS(i, n) Parrot_do_handle_events(i, 1, n)
+#define CHECK_EVENTS(i, n)  (opcode_t *)Parrot_do_check_events(i, n)
+#define HANDLE_EVENTS(i, n) (opcode_t *)Parrot_do_handle_events(i, 1, n)
 
 PARROT_API void Parrot_init_signals(void);
 PARROT_API void Parrot_init_events(Parrot_Interp);
