@@ -1,7 +1,7 @@
 /* global.h
  *  Copyright (C) 2004, The Perl Foundation.
  *  SVN Info
- *     $Id: /parrot/offline/include/parrot/global.h 3225 2006-12-29T03:28:40.817280Z coke  $
+ *     $Id: global.h 18210 2007-04-14 23:45:41Z jonathan $
  *  Overview:
  *      Contains accessor functions for globals
  *  Data Structure and Algorithms:
@@ -19,6 +19,9 @@ PARROT_API PMC *Parrot_get_namespace_keyed_str(Interp *, PMC *base_ns, STRING *s
 PARROT_API PMC *Parrot_make_namespace_keyed(Interp *, PMC *base_ns, PMC *pmc_key);
 PARROT_API PMC *Parrot_make_namespace_keyed_str(Interp *, PMC *base_ns, STRING *str_key);
 
+PARROT_API PMC *Parrot_get_namespace_autobase(Interp *interp, PMC *key);
+PARROT_API PMC *Parrot_make_namespace_autobase(Interp *interp, PMC *key);
+
 /*
  * {get,set}_global.
  *
