@@ -1,7 +1,7 @@
 /* memory.h
  *  Copyright (C) 2001-2003, The Perl Foundation.
  *  SVN Info
- *     $Id: /parrot/offline/include/parrot/memory.h 1257 2006-09-24T02:58:35.264419Z wcoleda  $
+ *     $Id: memory.h 17952 2007-04-03 02:00:50Z chromatic $
  *  Overview:
  *     This is the api header for the memory subsystem
  *  Data Structure and Algorithms:
@@ -41,6 +41,9 @@ void mem_setup_allocator(Interp *);
 #define mem_sys_memcopy memcpy
 #define mem_sys_memmove memmove
 
+#define mem_allocate_typed(type)    (type *)mem_sys_allocate(sizeof(type))
+#define mem_allocate_zeroed_typed(type) (type *)mem_sys_allocate_zeroed(sizeof(type))
+
 #endif /* PARROT_MEMORY_H_GUARD */
 
 /*
