@@ -1,7 +1,7 @@
 /* oplib.h
  *  Copyright (C) 2001-2003, The Perl Foundation.
  *  SVN Info
- *     $Id: /parrot/offline/include/parrot/oplib.h 1257 2006-09-24T02:58:35.264419Z wcoleda  $
+ *     $Id: oplib.h 17952 2007-04-03 02:00:50Z chromatic $
  *  Overview:
  *     Header file for op libraries.
  *  Data Structure and Algorithms:
@@ -31,7 +31,7 @@ typedef struct {
     int      patch_version;
     size_t      op_count;
     op_info_t * op_info_table;
-    void *      op_func_table;
+    op_func_t * op_func_table;
     int (*op_code)(const char * name, int full);
 } op_lib_t;
 
