@@ -1,7 +1,7 @@
 /* resources.h
  *  Copyright (C) 2001-2003, The Perl Foundation.
  *  SVN Info
- *     $Id: /parrot/offline/include/parrot/resources.h 4256 2007-03-03T01:16:13.129634Z coke  $
+ *     $Id: resources.h 18206 2007-04-14 20:50:06Z chromatic $
  *  Overview:
  *     Defines the resource allocation API
  *  Data Structure and Algorithms:
@@ -15,17 +15,17 @@
 
 #include "parrot/parrot.h"
 
-struct Memory_Block {
+typedef struct Memory_Block {
     size_t free;
     size_t size;
     struct Memory_Block *prev;
     struct Memory_Block *next;
     char *start;
     char *top;
-};
+} Memory_Block;
 
-struct Memory_Pool {
-    struct Memory_Block *top_block;
+typedef struct Memory_Pool {
+    Memory_Block *top_block;
     void (*compact)(Interp *, struct Memory_Pool *);
     size_t minimum_block_size;
     size_t total_allocated; /* total bytes allocated to this pool */
@@ -33,7 +33,7 @@ struct Memory_Pool {
     size_t possibly_reclaimable;     /* bytes that can possibly be reclaimed
                                       * (above plus COW-freed bytes) */
     FLOATVAL reclaim_factor; /* minimum percentage we will reclaim */
-};
+} Memory_Pool;
 
 
 
@@ -54,9 +54,9 @@ int Parrot_in_memory_pool(Interp *interp, void *bufstart);
 
 void Parrot_go_collect(Interp *);
 
-struct Arenas {
-    struct Memory_Pool *memory_pool;
-    struct Memory_Pool *constant_string_pool;
+typedef struct Arenas {
+    Memory_Pool *memory_pool;
+    Memory_Pool *constant_string_pool;
     struct Small_Object_Pool *string_header_pool;
     struct Small_Object_Pool *pmc_pool;
     struct Small_Object_Pool *pmc_ext_pool;
@@ -114,7 +114,7 @@ struct Arenas {
      * private data for the GC subsystem
      */
     void *  gc_private;         /* gc subsystem data */
-};
+} Arenas;
 
 /* &gen_from_enum(interpinfo.pasm) prefix(INTERPINFO_) */
 
@@ -141,7 +141,7 @@ typedef enum {
 
     /* interpinfo_s constants */
     EXECUTABLE_FULLNAME,
-    EXECUTABLE_BASENAME,
+    EXECUTABLE_BASENAME
 } Interpinfo_enum;
 
 /* &end_gen */
