@@ -1,7 +1,7 @@
 /* sub.h
  *  Copyright (C) 2001-2003, The Perl Foundation.
  *  SVN Info
- *     $Id: /parrot/offline/include/parrot/sub.h 4394 2007-03-12T04:18:36.612109Z coke  $
+ *     $Id: sub.h 18175 2007-04-13 06:53:20Z chromatic $
  *  Overview:
  *  Data Structure and Algorithms:
  *     Subroutine, coroutine, closure and continuation structures
@@ -87,8 +87,7 @@ typedef enum {
     SUB_COMP_FLAG_BIT_28 = 1 << 28,
     SUB_COMP_FLAG_BIT_29 = 1 << 29,
     SUB_COMP_FLAG_BIT_30 = 1 << 30,
-    SUB_COMP_FLAG_BIT_31 = 1 << 31,
-    SUB_COMP_FLAG_MASK   = 0x00000400,
+    SUB_COMP_FLAG_MASK   = 0x00000400
 } sub_comp_flags_enum;
 
 #define Sub_comp_get_FLAGS(o) ((PMC_sub(o))->comp_flags)
@@ -109,7 +108,13 @@ union parrot_context_t;
  * a flag to signal a Sub that a new RetContinuation should be created
  */
 
-#define NEED_CONTINUATION ((void*)1)
+#define NEED_CONTINUATION ((PMC *)1)
+
+/*
+ * maximum sub recursion depth
+ */
+
+#define RECURSION_LIMIT 1000
 
 /*
  * Sub and Closure share a Parrot_sub structure.
