@@ -1,4 +1,4 @@
-# $Id: /parrot/offline/languages/plumhead/lib/Parrot/Test/Plumhead.pm 4209 2007-02-28T02:03:42.197222Z coke  $
+# $Id: Plumhead.pm 17696 2007-03-22 22:22:34Z bernhard $
 
 package Parrot::Test::Plumhead;
 
@@ -35,7 +35,7 @@ Use plumhead.pl in smoke testing.
 =cut
 
 sub new {
-    my $test_module = $ENV{PARROT_PLUMHEAD_TEST_MODULE} || 'Parrot::Test::Plumhead::Phc2Past';
+    my $test_module = $ENV{PARROT_PLUMHEAD_TEST_MODULE} || 'Parrot::Test::Plumhead::Partridge';
 
     return bless {}, $test_module;
 }
