@@ -1,5 +1,5 @@
 # Copyright (C) 2004-2006, The Perl Foundation.
-# $Id: /parrot/offline/lib/Parrot/Distribution.pm 4664 2007-03-21T00:31:24.329638Z coke  $
+# $Id: Distribution.pm 18147 2007-04-11 21:02:56Z paultcochrane $
 
 =head1 NAME
 
@@ -184,7 +184,7 @@ BEGIN {
             ops => { file_exts => ['ops'] },
             lex => {
                 file_exts   => ['l'],
-                except_dirs => [ qw{ languages/lisp examples/library } ],
+                except_dirs => [qw{ languages/lisp examples/library }],
             },
             yacc => { file_exts => ['y'] },
             perl => {
@@ -339,10 +339,14 @@ This is to exclude automatically generated C-language files Parrot might have.
         my ( $self, $file ) = @_;
 
         push @exemptions => map { File::Spec->canonpath($_) } qw{
-            config/gen/cpu/i386/memcpy_mmx.c config/gen/cpu/i386/memcpy_sse.c
-            compilers/imcc/imclexer.c        compilers/imcc/imcparser.c
-            compilers/imcc/imcparser.h       languages/cola/lexer.c
-            languages/cola/parser.c          languages/cola/parser.h
+            config/gen/cpu/i386/memcpy_mmx.c
+            config/gen/cpu/i386/memcpy_sse.c
+            compilers/imcc/imclexer.c
+            compilers/imcc/imcparser.c
+            compilers/imcc/imcparser.h
+            languages/cola/lexer.c
+            languages/cola/parser.c
+            languages/cola/parser.h
             } unless @exemptions;
 
         $file->path =~ /\Q$_\E$/ && return 1 for @exemptions;
@@ -486,9 +490,7 @@ returns a Parrot::Docs::File object
 sub get_pir_language_files {
     my $self = shift;
 
-    my @pir_files = (
-        $self->pir_source_files,
-    );
+    my @pir_files = ( $self->pir_source_files, );
 
     return @pir_files;
 }
@@ -689,45 +691,49 @@ sub gen_manifest_skip {
 
     # manicheck.pl is probably only useful for checked out revisions
     # Checkout is done either with svn or svk
-    my $cmd = (-d '.svn') ? 'svn' : 'svk';
+    my $cmd = ( -d '.svn' ) ? 'svn' : 'svk';
 
     # Find all directories in the Parrot distribution
     my %dir_list = map {
+
         #uniq
         $_, undef;
-    } grep {
+        } grep {
+
         # directories only...
         -d $_
-    } map {
-        # extract directory component, if any 
+        } map {
+
+        # extract directory component, if any
         my $dir = ( File::Spec->splitpath($_) )[1];
-    } map {
-        # strip off any .svn components. 
+        } map {
+
+        # strip off any .svn components.
         # (lets us match dirs with no versioned files)
         s/\.svn.*//;
         $_;
-    } keys %{ ExtUtils::Manifest::manifind() }; # start with everything
+        } keys %{ ExtUtils::Manifest::manifind() };    # start with everything
 
-    $dir_list{'.'} = undef; # check top level directory too.
+    $dir_list{'.'} = undef;                            # check top level directory too.
 
-    my @skip;    # regular expressions for files to skip
+    my @skip;                                          # regular expressions for files to skip
 
-    my @dirs = (sort keys %dir_list);
+    my @dirs = ( sort keys %dir_list );
 
     my $ignore_cmd = "$cmd propget svn:ignore @dirs";
 
-    my ($patterns, $err, $code) = capture_output($ignore_cmd);
+    my ( $patterns, $err, $code ) = capture_output($ignore_cmd);
     die $err if $code;
 
-    my @patterns_list = split(/\n/, $patterns);
+    my @patterns_list = split( /\n/, $patterns );
     my ($dir);
-    foreach my $pattern ( @patterns_list ) {
+    foreach my $pattern (@patterns_list) {
 
         next if $pattern =~ m/^\s*$/;
-        
-        if ($pattern =~ s/^(.*?) - //) {
+
+        if ( $pattern =~ s/^(.*?) - // ) {
             $dir = $1;
-            if ($dir eq ".") {
+            if ( $dir eq "." ) {
                 $dir = q{};
             }
             else {
@@ -739,10 +745,10 @@ sub gen_manifest_skip {
         # whatever's left must be a pattern to ignore in the previously
         # found directory.
 
-        $pattern =~ s/\./\\./g;            # . is simply a dot
-        $pattern =~ s/\*/.*/g;             # * is any amount of chars
-        push @skip, "^${dir}$pattern\$"; # SVN globs are specific to a dir
-        push @skip, "^${dir}$pattern/";  # SVN globs are specific to a dir
+        $pattern =~ s/\./\\./g;    # . is simply a dot
+        $pattern =~ s/\*/.*/g;     # * is any amount of chars
+        push @skip, "^${dir}$pattern\$";    # SVN globs are specific to a dir
+        push @skip, "^${dir}$pattern/";     # SVN globs are specific to a dir
     }
 
     return \@skip;
