@@ -1,5 +1,5 @@
 # Copyright (C) 2004-2006, The Perl Foundation.
-# $Id: /parrot/offline/lib/Parrot/Pmc2c.pm 4558 2007-03-17T23:22:37.823693Z coke  $
+# $Id: Pmc2c.pm 18216 2007-04-15 03:31:19Z chromatic $
 
 =head1 NAME
 
@@ -26,7 +26,7 @@ use Parrot::PMC qw(%pmc_types);
 use Parrot::Pmc2c::UtilFunctions
     qw( gen_ret dont_edit count_newlines dynext_load_code c_code_coda );
 use Text::Balanced 'extract_bracketed';
-use Parrot::Pmc2c::PMETHODs;
+use Parrot::Pmc2c::PCCMETHOD;
 
 =back
 
@@ -337,7 +337,7 @@ sub includes {
 #include "parrot/dynext.h"
 EOC
 
-    $cout .= qq{#include "pmc_fixedintegerarray.h"\n} if ( $self->{flags}->{pmethod_present} );
+    $cout .= qq{#include "pmc_fixedintegerarray.h"\n} if ( $self->{flags}->{need_fia_header} );
     foreach my $parents ( $self->{class}, @{ $self->{parents} } ) {
         my $name = lc $parents;
         $cout .= qq{#include "pmc_$name.h"\n};
@@ -357,12 +357,13 @@ Prepends C<INTERP, SELF> to C<$args>.
 
 sub full_arguments {
     my $args = shift;
+    my $obj = shift || 'SELF';
 
     if ( $args =~ m/\S/ ) {
-        return "INTERP, SELF, $args";
+        return "INTERP, $obj, $args";
     }
     else {
-        return "INTERP, SELF";
+        return "INTERP, $obj";
     }
 }
 
@@ -415,7 +416,7 @@ sub proto {
     return $ret;
 }
 
-=item C<rewrite_nci_method($class, $method, $super, $super_table)>
+=item C<rewrite_nci_method($self, $class, $method, $super, $super_table)>
 
 Rewrites the method body performing the various macro substitutions for
 nci method bodies (see F<tools/build/pmc2c.pl>).
@@ -423,9 +424,23 @@ nci method bodies (see F<tools/build/pmc2c.pl>).
 =cut
 
 sub rewrite_nci_method {
-    my ( $class, $method ) = @_;
+    my ( $self, $class, $method ) = @_;
 
-    local $_ = $_[2];
+    local $_ = $_[3];
+
+    # Rewrite DYNSELF.other_method(args...)
+    s/\bDYNSELF\b           # Macro: DYNSELF
+      \.(\w+)           # other_method
+      \(\s*(.*?)\)      # capture argument list
+     /"pmc->vtable->$1(" . full_arguments($2) . ')'/xeg;
+
+    # Rewrite SELF.other_method(args...)
+    s/\bSELF\b              # Macro SELF
+      \.(\w+)           # other_method
+      \(\s*(.*?)\)      # capture argument list
+     /"Parrot_${class}" .
+      ($self->is_vtable_method($1) ? "" : "_nci") .
+      "_$1(" . full_arguments($2) . ")"/xeg;
 
     # Rewrite SELF -> pmc, INTERP -> interp
     s/\bSELF\b/pmc/g;
@@ -434,7 +449,7 @@ sub rewrite_nci_method {
     return $_;
 }
 
-=item C<rewrite_vtable_method($class, $method, $super, $super_table)>
+=item C<rewrite_vtable_method($self, $class, $method, $super, $super_table)>
 
 Rewrites the method body performing the various macro substitutions for
 vtable method bodies (see F<tools/build/pmc2c.pl>).
@@ -442,8 +457,8 @@ vtable method bodies (see F<tools/build/pmc2c.pl>).
 =cut
 
 sub rewrite_vtable_method {
-    my ( $class, $method, $super, $super_table ) = @_;
-    local $_ = $_[4];
+    my ( $self, $class, $method, $super, $super_table ) = @_;
+    local $_ = $_[5];
 
     # Rewrite method body
     my $supertype = "enum_class_$super";
@@ -483,13 +498,26 @@ sub rewrite_vtable_method {
       \.\bSELF\b            # Macro SELF
       \.(\w+)           # other_method
       \(\s*(.*?)\)      # capture argument list
-     /"Parrot_${1}_$2(" . full_arguments($3) . ')'/xeg;
+     /"Parrot_${1}" .
+      ($self->is_vtable_method($2) ? "" : "_nci") .
+      "_$2(" . full_arguments($3) . ')'/xeg;
+
+    # Rewrite OtherClass.object.other_method(args...)
+    s/(\w+)             # OtherClass
+      \.\b(\w+)\b       # any object
+      \.(\w+)           # other_method
+      \(\s*(.*?)\)      # capture argument list
+     /"Parrot_${1}" .
+      ($self->is_vtable_method($3) ? "" : "_nci") .
+      "_$3(" . full_arguments($4, $2) . ')'/xeg;
 
     # Rewrite SELF.other_method(args...)
     s/\bSELF\b              # Macro SELF
       \.(\w+)           # other_method
       \(\s*(.*?)\)      # capture argument list
-     /"Parrot_${class}_$1(".full_arguments($2).")"/xeg;
+     /"Parrot_${class}" .
+      ($self->is_vtable_method($1) ? "" : "_nci") .
+      "_$1(" . full_arguments($2) . ")"/xeg;
 
     # Rewrite SELF -> pmc, INTERP -> interp
     s/\bSELF\b/pmc/g;
@@ -522,12 +550,13 @@ sub body {
 
     my $total_body;
     if ( $method->{loc} eq 'vtable' ) {
-        $total_body = rewrite_vtable_method( $classname, $meth, $super, $self->{super}, $body );
+        $total_body =
+            $self->rewrite_vtable_method( $classname, $meth, $super, $self->{super}, $body );
     }
     else {
-        $total_body = rewrite_nci_method( $classname, $meth, $body );
+        $total_body = $self->rewrite_nci_method( $classname, $meth, $body );
     }
-    Parrot::Pmc2c::PMETHODs::rewrite_pminvoke( $method, \$total_body );
+    Parrot::Pmc2c::PCCMETHOD::rewrite_pccinvoke( $method, \$total_body );
 
     # now split into MMD if necessary:
     my $additional_bodies = '';
@@ -807,7 +836,7 @@ sub vtable_decl {
     my $enum_name = $self->{flags}{dynpmc} ? -1 : "enum_class_$classname";
     my $methlist = join( ",\n        ", @$methods );
     $cout .= <<ENDOFCODE;
-    const struct _vtable $name = {
+    const VTABLE $name = {
         NULL, /* namespace */
         $enum_name, /* base_type */
         NULL, /* whoami */
@@ -887,12 +916,12 @@ EOC
         /*
          * create vtable - clone it - we have to set a few items
          */
-        struct _vtable *vt_clone =
+        VTABLE *vt_clone =
             Parrot_clone_vtable(interp, &temp_base_vtable);
 EOC
     for my $k ( keys %extra_vt ) {
         $cout .= <<"EOC";
-        struct _vtable *vt_${k}_clone =
+        VTABLE *vt_${k}_clone =
             Parrot_clone_vtable(interp, &temp_${k}_vtable);
 EOC
     }
@@ -972,22 +1001,23 @@ EOC
     foreach my $method ( @{ $self->{methods} } ) {
         next unless $method->{loc} eq 'nci';
         my $proto = proto( $method->{type}, $method->{parameters} );
+        my $symbol_name = defined $method->{symbol} ? $method->{symbol} : $method->{meth};
         if ( exists $method->{pre_block} ) {
             $cout .= <<"EOC";
         register_raw_nci_method_in_ns(interp, entry,
-            F2DPTR(Parrot_${classname}_$method->{meth}), "$method->{meth}");
+            F2DPTR(Parrot_${classname}_$method->{meth}), "$symbol_name");
 EOC
         }
         else {
             $cout .= <<"EOC";
         enter_nci_method(interp, entry,
                 F2DPTR(Parrot_${classname}_$method->{meth}),
-                "$method->{meth}", "$proto");
+                "$symbol_name", "$proto");
 EOC
         }
         if ( $method->{attrs}{write} ) {
             $cout .= <<"EOC";
-        Parrot_mark_method_writes(interp, entry, "$method->{meth}");
+        Parrot_mark_method_writes(interp, entry, "$symbol_name");
 EOC
         }
     }
@@ -1174,6 +1204,14 @@ sub implements_vtable {
     return $self->{vtable}{methods}[$n]{mmd} =~ /MMD/ ? 0 : 1;
 }
 
+sub is_vtable_method {
+    my ( $self, $meth ) = @_;
+    foreach my $entry ( @{ $self->{vtable}{methods} } ) {
+        return 1 if $entry->{meth} eq $meth;
+    }
+    return 0;
+}
+
 =back
 
 =cut
