@@ -1,5 +1,5 @@
 # Copyright (C) 2004-2006, The Perl Foundation.
-# $Id: /parrot/offline/lib/Parrot/Pmc2c/Utils.pm 4558 2007-03-17T23:22:37.823693Z coke  $
+# $Id: Utils.pm 18147 2007-04-11 21:02:56Z paultcochrane $
 package Parrot::Pmc2c::Utils;
 use strict;
 use warnings;
@@ -8,7 +8,7 @@ use Data::Dumper;
 use Parrot::Vtable;
 use Parrot::Pmc2c::Library;
 use Parrot::Pmc2c::UtilFunctions qw(count_newlines);
-use Parrot::Pmc2c::PMETHODs;
+use Parrot::Pmc2c::PCCMETHOD;
 use Cwd qw(cwd realpath);
 use File::Basename;
 use Carp;
@@ -653,7 +653,7 @@ sub parse_pmc {
       (?:/\*.*?\*/)?    # C-like comments
     )*
 
-    (P?METHOD\s+)?        #method flag
+    ((?:PCC)?METHOD\s+)?        #method flag
 
     (\w+\**)            #type
       \s+
@@ -681,9 +681,13 @@ sub parse_pmc {
             attrs      => $attrs,
         };
 
-        if ( $flag and $flag =~ /PMETHOD/ ) {
-            Parrot::Pmc2c::PMETHODs::rewrite_pmethod($method_hash);
-            $flags_ref->{pmethod_present} = 1;
+        if ( $flag and $flag =~ /PCCMETHOD/ ) {
+            Parrot::Pmc2c::PCCMETHOD::rewrite_pccmethod($method_hash);
+            $flags_ref->{need_fia_header} = 1;
+        }
+
+        if ( $methodblock and $methodblock =~ /PCCINVOKE/ ) {
+            $flags_ref->{need_fia_header} = 1;
         }
 
         if ( $methodname eq 'class_init' ) {
@@ -691,10 +695,16 @@ sub parse_pmc {
         }
         else {
 
+            # Name-mangle NCI methods to avoid conflict with vtable methods.
+            if ($flag) {
+                $method_hash->{loc}    = "nci";
+                $method_hash->{meth}   = "nci_$methodname";
+                $method_hash->{symbol} = $methodname;
+            }
+
             # name => method idx mapping
-            $meth_hash{$methodname} = scalar @methods;
+            $meth_hash{ $method_hash->{meth} } = scalar @methods;
 
-            $method_hash->{loc} = "nci" if $flag;
             $method_hash->{mmds} = [ ( $methodblock =~ /MMD_(\w+):/g ) ];
             push @methods, $method_hash;
         }
