@@ -1,5 +1,5 @@
 # Copyright (C) 2004-2007, The Perl Foundation.
-# $Id: /parrot/offline/lib/Parrot/Test.pm 4558 2007-03-17T23:22:37.823693Z coke  $
+# $Id: Test.pm 17820 2007-03-29 01:12:34Z particle $
 
 =head1 NAME
 
@@ -271,7 +271,13 @@ sub run_command {
     }
 
     # Execute all commands
-    system($_ ) for ( @{$command} );
+    # [#42161] [BUG] Parrot::Test throws "Can't spawn" warning on windows
+    # ...if a system call returns a negative value
+    # removed exec warnings to prevent this warning from messing up test results
+    {
+        no warnings 'exec';
+        system($_ ) for ( @{$command} );
+    }
 
     if ($chdir) {
         chdir $orig_dir;
