@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2006, The Perl Foundation.
-$Id: /parrot/offline/src/debug.c 3225 2006-12-29T03:28:40.817280Z coke  $
+$Id: debug.c 18183 2007-04-14 03:15:44Z chromatic $
 
 =head1 NAME
 
@@ -449,7 +449,7 @@ PDB_next(Interp *interp, const char *command)
     pdb->state &= ~PDB_STOPPED;
 
     /* Execute */
-    for ( ; n && pdb->cur_opcode; n--)
+    for (; n && pdb->cur_opcode; n--)
         DO_OP(pdb->cur_opcode, pdb->debugee);
 
     /* Set the stopped flag */
@@ -496,7 +496,7 @@ PDB_trace(Interp *interp,
     pdb->state &= ~PDB_STOPPED;
 
     debugee = pdb->debugee;
-    for ( ; n && pdb->cur_opcode; n--) {
+    for (; n && pdb->cur_opcode; n--) {
         trace_op(debugee,
                 debugee->code->base.data,
                 debugee->code->base.data +
@@ -1284,7 +1284,7 @@ PDB_escape(const char *string, INTVAL length)
 
     fill = new = (char *)mem_sys_allocate(length * 2 + 1);
 
-    for ( ; string < end; string++) {
+    for (; string < end; string++) {
         switch (*string) {
             case '\0':
                 *(fill++) = '\\';
@@ -1339,7 +1339,7 @@ PDB_unescape(char *string)
     char *fill;
     int i, l = 0;
 
-    for ( ; *string; string++) {
+    for (; *string; string++) {
         l++;
         if (*string == '\\') {
             switch (string[1]) {
@@ -1970,9 +1970,16 @@ void
 PDB_eval(Interp *interp, const char *command)
 {
     opcode_t *run;
-    struct PackFile *eval_pf;
-    struct PackFile_ByteCode *old_cs;
+    PackFile *eval_pf;
+    PackFile_ByteCode *old_cs;
 
+    /*
+    The replacement code is almost certainly wrong. The previous
+    code is almost certainly wrong as well. Obviously, the
+    Parrot debugger needs some love.
+    */
+
+#if 0
     eval_pf = PDB_compile(interp, command);
 
     if (eval_pf) {
@@ -1982,11 +1989,17 @@ PDB_eval(Interp *interp, const char *command)
         Parrot_switch_to_cs(interp, old_cs, 1);
        /* TODO destroy packfile */
     }
+#endif
+
+    run = PDB_compile(interp, command);
+    if (run) {
+        DO_OP(run,interp);
+    }
 }
 
 /*
 
-=item C<struct PackFile *
+=item C<opcode_t *
 PDB_compile(Interp *interp, const char *command)>
 
 Compiles instructions with the PASM compiler.
@@ -2000,12 +2013,12 @@ which generates a malloced string.
 
 */
 
-struct PackFile *
+opcode_t *
 PDB_compile(Interp *interp, const char *command)
 {
     STRING *buf;
     const char *end = "\nend\n";
-    PMC * compiler, *code;
+    PMC * compiler;
     STRING *key = const_string(interp, "PASM");
     PMC *compreg_hash = VTABLE_get_pmc_keyed_int(interp,
             interp->iglobals, IGLOBALS_COMPREG_HASH);
@@ -2017,8 +2030,7 @@ PDB_compile(Interp *interp, const char *command)
     }
     buf = Parrot_sprintf_c(interp, "%s%s", command, end);
 
-    code = VTABLE_invoke(interp, compiler, buf);
-    return PMC_struct_val(code);
+    return VTABLE_invoke(interp, compiler, buf);
 }
 
 /*
@@ -2042,11 +2054,11 @@ PDB_extend_const_table(Interp *interp)
     if (interp->code->const_table->constants) {
         interp->code->const_table->constants =
             mem_sys_realloc(interp->code->const_table->constants,
-                            k * sizeof (struct PackFile_Constant *));
+                            k * sizeof (PackFile_Constant *));
     }
     else {
         interp->code->const_table->constants =
-            mem_sys_allocate(k * sizeof (struct PackFile_Constant *));
+            mem_sys_allocate(k * sizeof (PackFile_Constant *));
     }
 
     /* Allocate a new constant */
