@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2006, The Perl Foundation.
-$Id: /parrot/offline/src/embed.c 4602 2007-03-18T16:06:24.290113Z coke  $
+$Id: embed.c 18183 2007-04-14 03:15:44Z chromatic $
 
 =head1 NAME
 
@@ -252,7 +252,7 @@ Parrot_setwarnings(Interp *interp, Parrot_warnclass wc)
 
 /*
 
-=item C<struct PackFile *
+=item C<PackFile *
 Parrot_readbc(Interp *interp, const char *filename)>
 
 Read in a bytecode, unpack it into a C<PackFile> structure, and do fixups.
@@ -261,12 +261,12 @@ Read in a bytecode, unpack it into a C<PackFile> structure, and do fixups.
 
 */
 
-struct PackFile *
+PackFile *
 Parrot_readbc(Interp *interp, const char *fullname)
 {
     INTVAL program_size, wanted;
     char *program_code;
-    struct PackFile *pf;
+    PackFile *pf;
     FILE * io = NULL;
     INTVAL is_mapped = 0;
 #ifdef PARROT_HAS_HEADER_SYSMMAN
@@ -421,7 +421,7 @@ again:
 /*
 
 =item C<void
-Parrot_loadbc(Interp *interp, struct PackFile *pf)>
+Parrot_loadbc(Interp *interp, PackFile *pf)>
 
 Loads the C<PackFile> returned by C<Parrot_readbc()>.
 
@@ -430,10 +430,10 @@ Loads the C<PackFile> returned by C<Parrot_readbc()>.
 */
 
 void
-Parrot_loadbc(Interp *interp, struct PackFile *pf)
+Parrot_loadbc(Interp *interp, PackFile *pf)
 {
     if (pf == NULL) {
-        PIO_eprintf(interp, "Invalid packfile\n" );
+        PIO_eprintf(interp, "Invalid packfile\n");
         return;
     }
     interp->initial_pf = pf;
@@ -629,8 +629,7 @@ print_profile(Interp *interp, int status, void *p)
                         op_name(interp, k),
                         n,
                         t,
-                        (FLOATVAL)(t * 1000.0 / (FLOATVAL)n)
-                        );
+                        (FLOATVAL)(t * 1000.0 / (FLOATVAL)n));
             }
         }
 
@@ -639,8 +638,7 @@ print_profile(Interp *interp, int status, void *p)
                 "-",
                 call_count,
                 sum_time,
-                (FLOATVAL)(sum_time * 1000.0 / (FLOATVAL)call_count)
-                );
+                (FLOATVAL)(sum_time * 1000.0 / (FLOATVAL)call_count));
     }
 }
 
@@ -670,9 +668,9 @@ static PMC*
 set_current_sub(Interp *interp)
 {
     opcode_t i, ci;
-    struct PackFile_ByteCode *cur_cs;
-    struct PackFile_FixupTable *ft;
-    struct PackFile_ConstTable *ct;
+    PackFile_ByteCode *cur_cs;
+    PackFile_FixupTable *ft;
+    PackFile_ConstTable *ct;
     struct Parrot_sub *sub;
     PMC *sub_pmc;
     opcode_t *code_start;
@@ -863,6 +861,10 @@ Parrot_disassemble(Interp *interp)
     PDB_t *pdb;
     PDB_line_t *line;
     char *c;
+    int op_code_seq_num = 0;
+    int debugs;
+    int num_mappings;
+    int curr_mapping = 0;
 
     pdb = (PDB_t *)mem_sys_allocate_zeroed(sizeof (PDB_t));
 
@@ -872,7 +874,36 @@ Parrot_disassemble(Interp *interp)
     PDB_disassemble(interp, NULL);
     line = pdb->file->line;
 
+    debugs = (interp->code->debugs != NULL);
+
+    PIO_printf(interp, "%12s-%12s", "Seq_Op_Num", "Relative-PC");
+    if ( debugs ) {
+        PIO_printf(interp, " %6s:\n","SrcLn#");
+        num_mappings = interp->code->debugs->num_mappings;
+    }
+    else {
+        PIO_printf(interp, "\n");
+    }
     while (line->next) {
+        /* PIO_printf(interp, "%i < %i %i == %i \n", curr_mapping, num_mappings, op_code_seq_num, interp->code->debugs->mappings[curr_mapping]->offset); */
+        if (debugs && curr_mapping < num_mappings)
+        {
+            if ( op_code_seq_num == interp->code->debugs->mappings[curr_mapping]->offset)
+            {
+                int filename_const_offset = interp->code->debugs->mappings[curr_mapping]->u.filename;
+                PIO_printf(interp, "Current Source Filename %Ss\n", interp->code->const_table->constants[filename_const_offset]->u.string);
+                curr_mapping++;
+            }
+        }
+
+        PIO_printf(interp, "%012i-%012i", op_code_seq_num, line->opcode - interp->code->base.data);
+        if ( debugs ) {
+            PIO_printf(interp, " %06i: \t",interp->code->debugs->base.data[op_code_seq_num]);
+        }
+        else {
+            PIO_printf(interp, "\t");
+        }
+
         /* If it has a label print it */
         if (line->label)
             PIO_printf(interp, "L%li:\t", line->label->number);
@@ -881,6 +912,7 @@ Parrot_disassemble(Interp *interp)
             PIO_printf(interp, "%c", *(c++));
         PIO_printf(interp, "\n");
         line = line->next;
+        op_code_seq_num++;
     }
     return;
 }
@@ -905,12 +937,12 @@ void
 Parrot_run_native(Parrot_Interp interp, native_func_t func)
 {
     static opcode_t program_code[2];
-    struct PackFile *          pf;
+    PackFile *          pf;
 
     program_code[0] = interp->op_lib->op_code("enternative", 0);
     program_code[1] = 0; /* end */
     pf = PackFile_new(interp, 0);
-    pf->cur_cs = (struct PackFile_ByteCode *)
+    pf->cur_cs = (PackFile_ByteCode *)
         (pf->PackFuncs[PF_BYTEC_SEG].new_seg)(interp, pf, "code", 1);
     pf->cur_cs->base.data = program_code;
     pf->cur_cs->base.size = 2;
