@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2006, The Perl Foundation.
-$Id: /parrot/offline/src/exceptions.c 3225 2006-12-29T03:28:40.817280Z coke  $
+$Id: exceptions.c 18134 2007-04-11 06:36:43Z chromatic $
 
 =head1 NAME
 
@@ -235,7 +235,7 @@ find_exception_handler(Interp *interp, PMC *exception)
     message = VTABLE_get_string_keyed_int(interp, exception, 0);
     /* [TODO: replace quadratic search with something linear, hopefully without
        trashing abstraction layers.  -- rgr, 17-Sep-06.] */
-    while ((e = stack_entry(interp, interp->dynamic_env, depth))) {
+    while ((e = stack_entry(interp, interp->dynamic_env, depth)) != NULL) {
         if (e->entry_type == STACK_ENTRY_PMC) {
             handler = UVal_pmc(e->entry);
             if (handler && handler->vtable->base_type ==
@@ -317,7 +317,7 @@ pop_exception(Interp *interp)
     struct Parrot_cont * cc;
 
     PMC * const handler
-        = stack_peek(interp, interp->dynamic_env, &type);
+        = (PMC *)stack_peek(interp, interp->dynamic_env, &type);
 
     if (! handler
             || type != STACK_ENTRY_PMC
@@ -378,7 +378,7 @@ push_new_c_exception_handler(Interp *interp, Parrot_exception *jb)
 
 /*
 
-=item C<void *
+=item C<opcode_t *
 throw_exception(Interp *interp, PMC *exception, void *dest)>
 
 Throw the exception.
@@ -387,10 +387,10 @@ Throw the exception.
 
 */
 
-void *
+opcode_t *
 throw_exception(Interp *interp, PMC *exception, void *dest)
 {
-    void *address;
+    opcode_t *address;
 
     PMC * const handler = find_exception_handler(interp, exception);
     if (!handler)
@@ -409,7 +409,7 @@ throw_exception(Interp *interp, PMC *exception, void *dest)
 
 /*
 
-=item C<void *
+=item C<opcode_t *
 rethrow_exception(Interp *interp, PMC *exception)>
 
 Rethrow the exception.
@@ -418,11 +418,11 @@ Rethrow the exception.
 
 */
 
-void *
+opcode_t *
 rethrow_exception(Interp *interp, PMC *exception)
 {
     PMC *handler;
-    void *address;
+    opcode_t *address;
 
     if (exception->vtable->base_type != enum_class_Exception)
         PANIC("Illegal rethrow");
@@ -585,7 +585,7 @@ new_internal_exception(Interp *interp)
         interp->exc_free_list = the_exception->prev;
     }
     else
-        the_exception = mem_sys_allocate(sizeof (*the_exception));
+        the_exception = mem_allocate_typed(Parrot_exception);
     the_exception->prev = interp->exceptions;
     the_exception->resume = NULL;
     the_exception->msg = NULL;
@@ -612,6 +612,26 @@ free_internal_exception(Interp *interp)
     interp->exc_free_list = e;
 }
 
+void
+destroy_exception_list(Interp *interp)
+{
+    really_destroy_exception_list(interp->exceptions);
+    really_destroy_exception_list(interp->exc_free_list);
+}
+
+void
+really_destroy_exception_list(Parrot_exception *e)
+{
+    Parrot_exception *prev;
+
+    while (e != NULL)
+    {
+        prev = e->prev;
+        mem_sys_free(e);
+        e    = prev;
+    }
+}
+
 /*
 
 =item C<void
@@ -698,7 +718,7 @@ real_exception(Interp *interp, void *ret_addr,
                 "real_exception (severity:%d error:%d): %Ss\n"
                 "likely reason: argument count mismatch in main "
                 "(more than 1 param)\n",
-                EXCEPT_error, exitcode, msg );
+                EXCEPT_error, exitcode, msg);
         /* [what if exitcode is a multiple of 256?] */
         exit(exitcode);
     }
@@ -708,7 +728,7 @@ real_exception(Interp *interp, void *ret_addr,
     the_exception->resume = ret_addr;
     if (Interp_debug_TEST(interp, PARROT_BACKTRACE_DEBUG_FLAG)) {
         PIO_eprintf(interp, "real_exception (severity:%d error:%d): %Ss\n",
-            EXCEPT_error, exitcode, msg );
+            EXCEPT_error, exitcode, msg);
         PDB_backtrace(interp);
     }
     /*
@@ -729,7 +749,7 @@ void
 Parrot_init_exceptions(Interp *interp) {
     int i;
 
-    interp->exception_list = mem_sys_allocate(
+    interp->exception_list = (PMC **)mem_sys_allocate(
             sizeof (PMC*) * (E_LAST_PYTHON_E + 1));
     for (i = 0; i <= E_LAST_PYTHON_E; ++i) {
         PMC * const ex = pmc_new(interp, enum_class_Exception);
