@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2006, The Perl Foundation.
-$Id: /parrot/offline/src/exec.c 3225 2006-12-29T03:28:40.817280Z coke  $
+$Id: exec.c 18183 2007-04-14 03:15:44Z chromatic $
 
 =head1 NAME
 
@@ -69,7 +69,7 @@ Parrot_exec(Interp *interp, opcode_t *pc,
     extern PARROT_API int Parrot_exec_rel_count;
 
     Parrot_exec_objfile_t * const obj =
-        mem_sys_allocate_zeroed(sizeof (Parrot_exec_objfile_t));
+        mem_allocate_zeroed_typed(Parrot_exec_objfile_t);
     exec_init(obj);
     Parrot_exec_rel_addr = (char **)mem_sys_allocate_zeroed(4 * sizeof (char *));
     obj->bytecode_header_size =
@@ -87,7 +87,7 @@ Parrot_exec(Interp *interp, opcode_t *pc,
         sizeof (opcode_t *));
     /* const_table */
     add_data_member(obj, NULL, interp->code->const_table->const_count *
-        sizeof (struct PackFile_Constant));
+        sizeof (PackFile_Constant));
 #ifdef JIT_CGP
     /* prederef_code */
     j = (int)cgp_core;
@@ -206,7 +206,7 @@ Parrot_exec_add_symbol(Parrot_exec_objfile_t *obj /*NN*/,
         Parrot_exec_symbol_t *new_symbol;
 
         symbol_number = obj->symbol_count;
-        new_symbol = mem_sys_realloc(obj->symbol_table,
+        new_symbol = (Parrot_exec_symbol_t *)mem_sys_realloc(obj->symbol_table,
             (size_t)(obj->symbol_count + 1) * sizeof (Parrot_exec_symbol_t));
         obj->symbol_table = new_symbol;
 
@@ -266,8 +266,8 @@ Parrot_exec_add_text_rellocation(Parrot_exec_objfile_t *obj /*NN*/, char *nptr,
     extern PARROT_API char **Parrot_exec_rel_addr;
     extern PARROT_API int Parrot_exec_rel_count;
 
-    new_relloc = mem_sys_realloc(obj->text_rellocation_table,
-        (size_t)(obj->text_rellocation_count + 1)
+    new_relloc = (Parrot_exec_rellocation_t *)mem_sys_realloc(
+        obj->text_rellocation_table, (size_t)(obj->text_rellocation_count + 1)
             * sizeof (Parrot_exec_rellocation_t));
     obj->text_rellocation_table = new_relloc;
     new_relloc = &obj->text_rellocation_table[obj->text_rellocation_count++];
