@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2004, The Perl Foundation.
-$Id: /parrot/offline/src/global.c 4311 2007-03-06T14:55:52.509780Z coke  $
+$Id: global.c 18224 2007-04-15 16:56:33Z jonathan $
 
 =head1 NAME
 
@@ -39,7 +39,7 @@ static PMC * internal_ns_keyed(Interp *interp, PMC *base_ns, PMC *pmc_key,
 {
     PMC *ns, *sub_ns;
     INTVAL i, n;
-    static const INTVAL max_intval = (INTVAL)( (~(UINTVAL)0) >> 1); /*2s comp*/
+    static const INTVAL max_intval = (INTVAL)((~(UINTVAL)0) >> 1); /*2s comp*/
 
     ns = base_ns;
 
@@ -155,6 +155,54 @@ Parrot_make_namespace_keyed_str(Interp *interp, PMC *base_ns, STRING *str_key)
 }
 
 
+/*
+
+=item C<PMC *
+Parrot_get_namespace_autobase(Interp *, PMC *key)>
+
+Find a namespace with the key C<key>, which may be a String, a Key, or an
+array of strings. If it is a String, then the lookup is relative to the
+current namespace. Otherwise, it is relative to the current HLL root
+namespace. Return the namespace, or NULL if not found.
+
+=item C<PMC *
+Parrot_make_namespace_autobase(Interp *, PMC *pmc_key)>
+
+Find, or create if necessary, a namespace with the key C<key>, which may be a
+String, a Key, or an array of strings. If it is a String, then the lookup is
+relative to the current namespace. Otherwise, it is relative to the current HLL
+root namespace. Return the namespace.  Errors will result in exceptions.
+
+=cut
+
+*/
+
+
+PMC *
+Parrot_make_namespace_autobase(Interp *interp, PMC *key)
+{
+    PMC *base_ns;
+    if (VTABLE_isa(interp, key, string_from_const_cstring(interp, "String", 0)))
+        base_ns = CONTEXT(interp->ctx)->current_namespace;
+    else
+        base_ns = VTABLE_get_pmc_keyed_int(interp, interp->HLL_namespace,
+            CONTEXT(interp->ctx)->current_HLL);
+    return Parrot_make_namespace_keyed(interp, base_ns, key);
+}
+
+PMC *
+Parrot_get_namespace_autobase(Interp *interp, PMC *key)
+{
+    PMC *base_ns;
+    if (VTABLE_isa(interp, key, string_from_const_cstring(interp, "String", 0)))
+        base_ns = CONTEXT(interp->ctx)->current_namespace;
+    else
+        base_ns = VTABLE_get_pmc_keyed_int(interp, interp->HLL_namespace,
+            CONTEXT(interp->ctx)->current_HLL);
+    return Parrot_get_namespace_keyed(interp, base_ns, key);
+}
+
+
 /*
 
 =item C<PMC *
@@ -486,7 +534,7 @@ store_sub_in_multi(Parrot_Interp interp, PMC *sub, PMC *ns)
         VTABLE_push_pmc(interp, multisub, sub);
 
     c_meth = string_to_cstring(interp, subname);
-    if ( (func_nr = Parrot_MMD_method_idx(interp, c_meth))  >= 0) {
+    if ((func_nr = Parrot_MMD_method_idx(interp, c_meth))  >= 0) {
         Parrot_mmd_rebuild_table(interp, -1, func_nr);
     }
     string_cstring_free(c_meth);
@@ -508,7 +556,7 @@ Parrot_store_sub_in_namespace(Parrot_Interp interp, PMC *sub)
     PMC_sub(sub)->namespace_stash = ns;
 
     /* store a :multi sub */
-    if (!PMC_IS_NULL( PMC_sub(sub)->multi_signature) )
+    if (!PMC_IS_NULL(PMC_sub(sub)->multi_signature))
         store_sub_in_multi(interp, sub, ns);
     /* store other subs (as long as they're not :anon) */
     else if (!(PObj_get_FLAGS(sub) & SUB_FLAG_PF_ANON)) {
