@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2005, The Perl Foundation.
-$Id: /parrot/offline/src/hll.c 4104 2007-02-20T19:43:50.939144Z coke  $
+$Id: hll.c 18216 2007-04-15 03:31:19Z chromatic $
 
 =head1 NAME
 
@@ -112,8 +112,7 @@ new_hll_entry(Interp *interp)
 }
 
 INTVAL
-Parrot_register_HLL(Interp *interp,
-        STRING *hll_name, STRING *hll_lib)
+Parrot_register_HLL(Interp *interp, STRING *hll_name, STRING *hll_lib)
 {
     PMC *entry, *name, *type_hash, *ns_hash, *hll_info;
     INTVAL idx;
