@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2003, The Perl Foundation.
-$Id: /parrot/offline/src/inter_call.c 4271 2007-03-03T13:32:44.422911Z coke  $
+$Id: inter_call.c 18209 2007-04-14 23:42:36Z jonathan $
 
 =head1 NAME
 
@@ -37,18 +37,18 @@ subroutines.
         orig.bp_ps = save.bp_ps;
 
 
-static int next_arg(Interp *, struct call_state_item *st);
-static void next_arg_sig(Interp *interp, struct call_state_item *st);
-static int set_retval_util(Parrot_Interp interp, const char *sig, parrot_context_t *ctx,
-        struct call_state *st);
+static int next_arg(Interp *, call_state_item *st);
+static void next_arg_sig(Interp *interp, call_state_item *st);
+static int set_retval_util(Parrot_Interp interp, const char *sig,
+    parrot_context_t *ctx, call_state *st);
 
 /*
 
-=item C<int Parrot_init_arg_nci(Interp *, struct call_state *st, const char *sig)>
+=item C<int Parrot_init_arg_nci(Interp *, call_state *st, const char *sig)>
 
 Initialize the argument passing state C<call_state> for the given NCI signature.
 
-=item C<int Parrot_init_ret_nci(Interp *, struct call_state *st, const char *sig)>
+=item C<int Parrot_init_ret_nci(Interp *, call_state *st, const char *sig)>
 
 Initialize the return value passing state C<call_state> for the given NCI signature.
 
@@ -57,15 +57,19 @@ Initialize the return value passing state C<call_state> for the given NCI signat
 */
 
 int
-Parrot_init_arg_nci(Interp *interp, struct call_state *st, const char *sig)
+Parrot_init_arg_nci(Interp *interp, call_state *st, const char *sig)
 {
-    Parrot_init_arg_op(interp, CONTEXT(interp->ctx), interp->current_args, &st->src);
+    if (PMC_IS_NULL(interp->args_signature))
+        Parrot_init_arg_op(interp, CONTEXT(interp->ctx), interp->current_args, &st->src);
+    else
+        Parrot_init_arg_indexes_and_sig_pmc(interp, CONTEXT(interp->ctx),
+            interp->current_args, interp->args_signature, &st->src);
     Parrot_init_arg_sig(interp, CONTEXT(interp->ctx), sig, NULL, &st->dest);
     return 1;
 }
 
 int
-Parrot_init_ret_nci(Interp *interp, struct call_state *st, const char *sig)
+Parrot_init_ret_nci(Interp *interp, call_state *st, const char *sig)
 {
     struct Parrot_Context *ctx = CONTEXT(interp->ctx);
     PMC *current_cont = ctx->current_cont;
@@ -85,20 +89,20 @@ Parrot_init_ret_nci(Interp *interp, struct call_state *st, const char *sig)
 
 /*
 int
-=item C<Parrot_init_arg_indexes_and_sig_pmc(Interp *interp, parrot_context_t *ctx,
-        opcode_t *indexes, PMC* sig_pmc, struct call_state_item *st)>
+=item C<Parrot_init_arg_indexes_and_sig_pmc(Interp *interp,
+    parrot_context_t *ctx, opcode_t *indexes, PMC* sig_pmc, call_state_item *st)>
 
 Initialize argument transfer with given context registers, register indexes, and
 a signature pmc.
 
 =item C<int Parrot_init_arg_sig(Interp *, parrot_context_t *ctx,
-        const char *sig, void *ap, struct call_state_item *st)>
+        const char *sig, void *ap, call_state_item *st)>
 
 Initialize argument transfer with given code segment (holding the
 const_table), registers, function signature, and arguments.
 
-=item C<int Parrot_init_arg_op(Interp *, parrot_context_t *ctx,
-        opcode_t *pc, struct call_state_item *st)>
+=item C<int Parrot_init_arg_op(Interp *, parrot_context_t *ctx, opcode_t *pc,
+    call_state_item *st)>
 
 Initialize argument transfer with given context registers, and opcode
 location of a get_ or set_ argument opcode.
@@ -114,7 +118,7 @@ These functions return 0, if no arguments are present, or 1 on success.
 
 int
 Parrot_init_arg_indexes_and_sig_pmc(Interp *interp, parrot_context_t *ctx,
-        opcode_t *indexes, PMC* sig_pmc, struct call_state_item *st)
+        opcode_t *indexes, PMC* sig_pmc, call_state_item *st)
 {
     if (!sig_pmc && indexes) {
         ++indexes;
@@ -143,8 +147,8 @@ Parrot_init_arg_indexes_and_sig_pmc(Interp *interp, parrot_context_t *ctx,
 }
 
 int
-Parrot_init_arg_op(Interp *interp, parrot_context_t *ctx,
-        opcode_t *pc, struct call_state_item *st)
+Parrot_init_arg_op(Interp *interp, parrot_context_t *ctx, opcode_t *pc,
+    call_state_item *st)
 {
     PMC *sig_pmc = PMCNULL;
     if (pc) {
@@ -157,8 +161,8 @@ Parrot_init_arg_op(Interp *interp, parrot_context_t *ctx,
 }
 
 int
-Parrot_init_arg_sig(Interp *interp, parrot_context_t *ctx,
-        const char *sig, void *ap, struct call_state_item *st)
+Parrot_init_arg_sig(Interp *interp, parrot_context_t *ctx, const char *sig,
+    void *ap, call_state_item *st)
 {
     st->i = 0;
     st->n = 0;
@@ -181,7 +185,7 @@ Parrot_init_arg_sig(Interp *interp, parrot_context_t *ctx,
  * PMC being flattened, and fetch the first arg from the flattened set.
  */
 static void
-start_flatten(Interp *interp, struct call_state *st, PMC *p_arg)
+start_flatten(Interp *interp, call_state *st, PMC *p_arg)
 {
     if (PARROT_ARG_NAME_ISSET(st->src.sig)) {
         /* src ought to be an hash */
@@ -212,7 +216,7 @@ start_flatten(Interp *interp, struct call_state *st, PMC *p_arg)
 
 
 static void
-next_arg_sig(Interp *interp, struct call_state_item *st)
+next_arg_sig(Interp *interp, call_state_item *st)
 {
     switch (st->mode & CALL_S_D_MASK) {
         case CALL_STATE_OP:
@@ -239,7 +243,7 @@ next_arg_sig(Interp *interp, struct call_state_item *st)
 }
 
 static int
-next_arg(Interp *interp, struct call_state_item *st)
+next_arg(Interp *interp, call_state_item *st)
 {
     st->i++;
     if (st->i >= st->n) {
@@ -252,7 +256,7 @@ next_arg(Interp *interp, struct call_state_item *st)
 }
 
 static void
-fetch_arg_sig(Interp *interp, struct call_state *st)
+fetch_arg_sig(Interp *interp, call_state *st)
 {
     va_list *ap = (va_list*)(st->src.u.sig.ap);
     switch (st->src.sig & PARROT_ARG_TYPE_MASK) {
@@ -282,7 +286,7 @@ fetch_arg_sig(Interp *interp, struct call_state *st)
 
 
 static void
-fetch_arg_op(Interp *interp, struct call_state *st)
+fetch_arg_op(Interp *interp, call_state *st)
 {
     int constant = PARROT_ARG_CONSTANT_ISSET(st->src.sig);
     INTVAL idx = st->src.u.op.pc[st->src.i];
@@ -314,7 +318,7 @@ fetch_arg_op(Interp *interp, struct call_state *st)
 
 
 int
-Parrot_fetch_arg(Interp *interp, struct call_state *st)
+Parrot_fetch_arg(Interp *interp, call_state *st)
 {
     if (st->dest.mode & CALL_STATE_NEXT_ARG) {
         if (!next_arg(interp, &st->dest))
@@ -348,7 +352,8 @@ Parrot_fetch_arg(Interp *interp, struct call_state *st)
             PMC *elem;
             if (st->key) {
                 st->src.slurp_i++;
-                st->name = parrot_hash_get_idx(interp, PMC_struct_val(st->src.slurp), st->key);
+                st->name = (STRING *)parrot_hash_get_idx(interp,
+                               (Hash *)PMC_struct_val(st->src.slurp), st->key);
                 assert(st->name);
                 elem = VTABLE_get_pmc_keyed_str(interp, st->src.slurp, st->name);
             }
@@ -385,7 +390,7 @@ Parrot_fetch_arg(Interp *interp, struct call_state *st)
 
 
 int
-Parrot_fetch_arg_nci(Interp *interp, struct call_state *st)
+Parrot_fetch_arg_nci(Interp *interp, call_state *st)
 {
     Parrot_fetch_arg(interp, st);
     if (st->dest.sig & PARROT_ARG_SLURPY_ARRAY) {
@@ -408,7 +413,7 @@ Parrot_fetch_arg_nci(Interp *interp, struct call_state *st)
 }
 
 static void
-convert_arg_from_int(Interp *interp, struct call_state *st)
+convert_arg_from_int(Interp *interp, call_state *st)
 {
     PMC *d;
 
@@ -428,7 +433,7 @@ convert_arg_from_int(Interp *interp, struct call_state *st)
 }
 
 static void
-convert_arg_from_num(Interp *interp, struct call_state *st)
+convert_arg_from_num(Interp *interp, call_state *st)
 {
     PMC *d;
 
@@ -448,7 +453,7 @@ convert_arg_from_num(Interp *interp, struct call_state *st)
 }
 
 static void
-convert_arg_from_str(Interp *interp, struct call_state *st)
+convert_arg_from_str(Interp *interp, call_state *st)
 {
     PMC *d;
 
@@ -468,7 +473,7 @@ convert_arg_from_str(Interp *interp, struct call_state *st)
 }
 
 static void
-convert_arg_from_pmc(Interp *interp, struct call_state *st)
+convert_arg_from_pmc(Interp *interp, call_state *st)
 {
     switch (st->dest.sig & PARROT_ARG_TYPE_MASK) {
         case PARROT_ARG_INTVAL:
@@ -489,7 +494,7 @@ convert_arg_from_pmc(Interp *interp, struct call_state *st)
  * to pass a key to a tailcalled function or method
  */
 static void
-clone_key_arg(Interp *interp, struct call_state *st)
+clone_key_arg(Interp *interp, call_state *st)
 {
     PMC *key = UVal_pmc(st->val);
 
@@ -513,7 +518,7 @@ clone_key_arg(Interp *interp, struct call_state *st)
  * initializes dest calling state for recption of first named arg.
  */
 static void
-init_first_dest_named(Interp *interp, struct call_state *st)
+init_first_dest_named(Interp *interp, call_state *st)
 {
     int i, n_named, idx;
     INTVAL sig;
@@ -564,7 +569,7 @@ init_first_dest_named(Interp *interp, struct call_state *st)
  * locate destination pos, return 0 if state changed
  */
 static int
-locate_pos_named(Interp *interp, struct call_state *st)
+locate_pos_named(Interp *interp, call_state *st)
 {
     int i, n_named;
     INTVAL sig;
@@ -595,7 +600,7 @@ locate_pos_named(Interp *interp, struct call_state *st)
  * locate destination name, return 0 if not found
  */
 static int
-locate_named_named(Interp *interp, struct call_state *st)
+locate_named_named(Interp *interp, call_state *st)
 {
     int i, n_named, idx;
     INTVAL sig;
@@ -633,7 +638,7 @@ locate_named_named(Interp *interp, struct call_state *st)
 }
 
 static void
-store_arg(struct call_state *st, INTVAL idx)
+store_arg(call_state *st, INTVAL idx)
 {
     switch (st->dest.sig & PARROT_ARG_TYPE_MASK) {
         case PARROT_ARG_INTVAL:
@@ -652,7 +657,7 @@ store_arg(struct call_state *st, INTVAL idx)
 }
 
 static int
-store_current_arg(Interp *interp, struct call_state *st)
+store_current_arg(Interp *interp, call_state *st)
 {
     INTVAL idx;
     if (st->dest.i >= st->dest.n)
@@ -667,7 +672,7 @@ store_current_arg(Interp *interp, struct call_state *st)
 }
 
 int
-Parrot_store_arg(Interp *interp, struct call_state *st)
+Parrot_store_arg(Interp *interp, call_state *st)
 {
     if (!store_current_arg(interp, st))
         return 0;
@@ -679,7 +684,7 @@ Parrot_store_arg(Interp *interp, struct call_state *st)
 
 
 static void
-create_slurpy_array(Interp *interp, struct call_state *st, INTVAL idx)
+create_slurpy_array(Interp *interp, call_state *st, INTVAL idx)
 {
     st->dest.slurp =
         pmc_new(interp, Parrot_get_ctx_HLL_type(interp, enum_class_ResizablePMCArray));
@@ -694,7 +699,7 @@ create_slurpy_array(Interp *interp, struct call_state *st, INTVAL idx)
 }
 
 static void
-too_few(Interp *interp, struct call_state *st, const char *action)
+too_few(Interp *interp, call_state *st, const char *action)
 {
     int max_expected_args = st->params;
     int min_expected_args = max_expected_args - st->optionals;
@@ -708,7 +713,7 @@ too_few(Interp *interp, struct call_state *st, const char *action)
 }
 
 static void
-too_many(Interp *interp, struct call_state *st, const char *action)
+too_many(Interp *interp, call_state *st, const char *action)
 {
     int max_expected_args = st->params;
     int min_expected_args = max_expected_args - st->optionals;
@@ -722,7 +727,7 @@ too_many(Interp *interp, struct call_state *st, const char *action)
 }
 
 static void
-null_val(int sig, struct call_state *st)
+null_val(int sig, call_state *st)
 {
     switch (sig & PARROT_ARG_TYPE_MASK) {
         case PARROT_ARG_INTVAL:
@@ -744,7 +749,7 @@ null_val(int sig, struct call_state *st)
  * STRING* name, [INPS] actual_arg, int opt_arg_flag
  */
 static void
-check_named(Interp *interp, struct call_state *st, const char *action)
+check_named(Interp *interp, call_state *st, const char *action)
 {
     int i;
     int n_named = -1;
@@ -754,7 +759,7 @@ check_named(Interp *interp, struct call_state *st, const char *action)
 
         /* verify that a name exists */
         INTVAL sig = st->dest.sig = SIG_ITEM(st->dest.u.op.signature, i);
-        if(sig & PARROT_ARG_NAME)
+        if (sig & PARROT_ARG_NAME)
         {
             INTVAL arg_sig;
             int last_name_pos;
@@ -772,7 +777,7 @@ check_named(Interp *interp, struct call_state *st, const char *action)
             /* if this named arg is already filled, continue*/
             if (st->named_done & (1 << n_named)) {
                 arg_sig = st->dest.sig = SIG_ITEM(st->dest.u.op.signature, i+1);
-                if(arg_sig & PARROT_ARG_OPT_FLAG)
+                if (arg_sig & PARROT_ARG_OPT_FLAG)
                     i++; /* skip associated opt flag arg as well */
                 continue;
             }
@@ -782,7 +787,7 @@ check_named(Interp *interp, struct call_state *st, const char *action)
                 store_arg(st, idx);
 
                 arg_sig = st->dest.sig = SIG_ITEM(st->dest.u.op.signature, i+1);
-                if(arg_sig & PARROT_ARG_OPT_FLAG) {
+                if (arg_sig & PARROT_ARG_OPT_FLAG) {
                     i++;
                     idx = st->dest.u.op.pc[i];
                     CTX_REG_INT(st->dest.ctx, idx) = 0;
@@ -807,18 +812,18 @@ check_named(Interp *interp, struct call_state *st, const char *action)
 }
 
 static void
-init_call_stats(struct call_state *st)
+init_call_stats(call_state *st)
 {
     st->n_actual_args = st->src.n;  /* initial guess, adjusted for :flat args */
-    st->optionals = 0;
-    st->params = st->dest.n;
-    st->name = NULL;
-    st->key = NULL;
-    st->first_named = -1;
+    st->optionals     = 0;
+    st->params        = st->dest.n;
+    st->name          = NULL;
+    st->key           = NULL;
+    st->first_named   = -1;
 }
 
 void
-Parrot_process_args(Interp *interp, struct call_state *st, arg_pass_t param_or_result)
+Parrot_process_args(Interp *interp, call_state *st, arg_pass_t param_or_result)
 {
     int state, opt_flag;
     int err_check = 1;
@@ -854,7 +859,8 @@ Parrot_process_args(Interp *interp, struct call_state *st, arg_pass_t param_or_r
          */
         if (!(state & CALL_STATE_NAMED_x)) {
             if (!(state & CALL_STATE_SLURP) &&
-                    (st->dest.sig & (PARROT_ARG_SLURPY_ARRAY|PARROT_ARG_NAME)) == PARROT_ARG_SLURPY_ARRAY) {
+                    (st->dest.sig & (PARROT_ARG_SLURPY_ARRAY|PARROT_ARG_NAME))
+                    == PARROT_ARG_SLURPY_ARRAY) {
                 /* create dest slurp array */
                 idx = st->dest.u.op.pc[st->dest.i];
                 assert(idx >= 0);
@@ -1007,9 +1013,9 @@ Parrot_process_args(Interp *interp, struct call_state *st, arg_pass_t param_or_r
 }
 
 void
-Parrot_convert_arg(Interp *interp, struct call_state *st)
+Parrot_convert_arg(Interp *interp, call_state *st)
 {
-#define END_OF_ARGS(x) (x.i >= x.n )
+#define END_OF_ARGS(x) (x.i >= x.n)
     /* if END OF SRC or DEST ARGS, no need to convert */
     if ((END_OF_ARGS(st->src) || END_OF_ARGS(st->dest)))
         return;
@@ -1067,7 +1073,7 @@ void
 parrot_pass_args(Interp *interp, parrot_context_t *src_ctx, parrot_context_t *dest_ctx,
         opcode_t *src_indexes, opcode_t *dest_indexes, arg_pass_t  param_or_result)
 {
-    struct call_state st;
+    call_state st;
     PMC* src_signature;
     PMC* dest_signature;
 
@@ -1108,7 +1114,7 @@ opcode_t *
 parrot_pass_args_fromc(Interp *interp, const char *sig,
         opcode_t *dest, parrot_context_t *old_ctxp, va_list ap)
 {
-    struct call_state st;
+    call_state st;
 
     Parrot_init_arg_op(interp, CONTEXT(interp->ctx), dest, &st.dest);
     Parrot_init_arg_sig(interp, old_ctxp, sig, PARROT_VA_TO_VAPTR(ap), &st.src);
@@ -1117,7 +1123,8 @@ parrot_pass_args_fromc(Interp *interp, const char *sig,
 }
 
 int
-set_retval_util(Parrot_Interp interp, const char *sig, parrot_context_t *ctx, struct call_state *st)
+set_retval_util(Parrot_Interp interp, const char *sig, parrot_context_t *ctx,
+        call_state *st)
 {
     opcode_t *src_pc = interp->current_returns;
     int todo = Parrot_init_arg_op(interp, ctx, src_pc, &st->src);
@@ -1141,7 +1148,7 @@ set_retval_util(Parrot_Interp interp, const char *sig, parrot_context_t *ctx, st
 void*
 set_retval(Parrot_Interp interp, int sig_ret, parrot_context_t *ctx)
 {
-    struct call_state st;
+    call_state st;
 
     if (!sig_ret || sig_ret == 'v')
         return NULL;
@@ -1163,7 +1170,7 @@ set_retval(Parrot_Interp interp, int sig_ret, parrot_context_t *ctx)
 INTVAL
 set_retval_i(Parrot_Interp interp, int sig_ret, parrot_context_t *ctx)
 {
-    struct call_state st;
+    call_state st;
 
     if (sig_ret != 'I')
         real_exception(interp, NULL, E_ValueError, "return signature not 'I'");
@@ -1180,7 +1187,7 @@ set_retval_i(Parrot_Interp interp, int sig_ret, parrot_context_t *ctx)
 FLOATVAL
 set_retval_f(Parrot_Interp interp, int sig_ret, parrot_context_t *ctx)
 {
-    struct call_state st;
+    call_state st;
 
     if (sig_ret != 'N')
         real_exception(interp, NULL, E_ValueError, "return signature not 'N'");
@@ -1197,7 +1204,7 @@ set_retval_f(Parrot_Interp interp, int sig_ret, parrot_context_t *ctx)
 STRING*
 set_retval_s(Parrot_Interp interp, int sig_ret, parrot_context_t *ctx)
 {
-    struct call_state st;
+    call_state st;
 
     if (sig_ret != 'S')
         real_exception(interp, NULL, E_ValueError, "return signature not 'S'");
@@ -1214,7 +1221,7 @@ set_retval_s(Parrot_Interp interp, int sig_ret, parrot_context_t *ctx)
 PMC*
 set_retval_p(Parrot_Interp interp, int sig_ret, parrot_context_t *ctx)
 {
-    struct call_state st;
+    call_state st;
 
     if (sig_ret != 'P')
         real_exception(interp, NULL, E_ValueError, "return signature not 'P'");
@@ -1225,6 +1232,325 @@ set_retval_p(Parrot_Interp interp, int sig_ret, parrot_context_t *ctx)
     return NULL;
 }
 
+/*
+ * commit_last_arg is called by Parrot_PCCINVOKE when it reaches the end of each arg
+ * in the arg signature.  see Parrot_PCCINVOKE for signature syntax.
+ */
+static void
+commit_last_arg(Interp *interp, int index, int cur, opcode_t *n_regs_used, int seen_arrow,
+        PMC **sigs, opcode_t **indexes, parrot_context_t *ctx, PMC *pmc, va_list *list)
+{
+    int reg_offset = 0;
+
+    /* invocant already commited, just return */
+    if (seen_arrow == 0 && index == 0 && pmc)
+        return;
+
+    /* calculate arg's register offset */
+    switch (cur & PARROT_ARG_TYPE_MASK) { /* calc reg offset */
+        case PARROT_ARG_INTVAL:
+            reg_offset = n_regs_used[seen_arrow * 4 + REGNO_INT]++; break;
+        case PARROT_ARG_FLOATVAL:
+            reg_offset = n_regs_used[seen_arrow * 4 + REGNO_NUM]++; break;
+        case PARROT_ARG_STRING:
+            reg_offset = n_regs_used[seen_arrow * 4 + REGNO_STR]++; break;
+        case PARROT_ARG_PMC :
+            reg_offset = n_regs_used[seen_arrow * 4 + REGNO_PMC]++; break;
+        default:
+                  real_exception(interp, NULL, E_IndexError,
+                          "Parrot_PCCINVOKE: invalid reg type");
+    }
+
+    /* set the register offset into the index int[] */
+    indexes[seen_arrow][index] = reg_offset;
+    /* set the PARROT_ARG_FLAGS into the signature FIA */
+    VTABLE_set_integer_keyed_int(interp, sigs[seen_arrow], index, cur);
+
+    /* perform the arg accessor function, assigning the arg to its corresponding register */
+    if (!seen_arrow) {
+        switch (cur & PARROT_ARG_TYPE_MASK) {
+            case PARROT_ARG_INTVAL:
+                CTX_REG_INT(ctx, reg_offset) = va_arg(*list, INTVAL); break;
+            case PARROT_ARG_FLOATVAL:
+                CTX_REG_NUM(ctx, reg_offset) = va_arg(*list, FLOATVAL); break;
+            case PARROT_ARG_STRING:
+                CTX_REG_STR(ctx, reg_offset) = va_arg(*list, STRING*); break;
+            case PARROT_ARG_PMC:
+                CTX_REG_PMC(ctx, reg_offset) = va_arg(*list, PMC*); break;
+            default:
+                      real_exception(interp, NULL, E_IndexError,
+                          "Parrot_PCCINVOKE: invalid reg type");
+        }
+    }
+}
+
+#define MAX(a,b) (((a)) > (b) ? (a) : (b))
+
+/*
+
+=item C<void
+Parrot_PCCINVOKE(Interp* interp, PMC* pmc, STRING *method_name, const char *signature, ... )>
+
+pmc is the invocant.
+method_name is the method_name used in the find_method VTABLE call
+signature is a DSL describing parrot calling convention for Parrot_PCCINVOKE.
+... variable args contains the IN arguments followed by the OUT results variables.
+    you must pass the address_of(&) the OUT results of course.
+
+Signatures:
+  uppercase letters repesent each arg and denote its types
+  I INTVAL
+  N FLOATVAL
+  S STRING*
+  P PMC*
+
+  lowercase letters are adverb modifiers to the preceeding uppercase arg identifier
+  f flatten
+  n named
+  s slurpy
+
+  -> is the separator between args and results, similar to type theory notation.
+
+  Named args require two arg slots, the first is the name, the second is the arg
+
+Example signature
+  "SnIPf->INPs"
+  The args to the method invocation are
+    a named INTVAL:  SnI
+    a flattened PMC:  Pf
+  The results of the method invocation are
+    a INTVAL: I
+    a FLOATVAL: N
+    a slurpy PMC: Ps
+
+invokes a PMC method
+=cut
+
+*/
+
+void
+Parrot_PCCINVOKE(Interp* interp, PMC* pmc, STRING *method_name, const char *signature, ...)
+{
+#define PCC_ARG_MAX 1024
+    /* variables from PCCINVOKE impl in PCCMETHOD.pm */
+    INTVAL n_regs_used[] = { 0, 0, 0, 0, 0, 0, 0, 0 }; /* args INSP, returns INSP */
+    opcode_t arg_indexes[PCC_ARG_MAX];
+    opcode_t result_indexes[PCC_ARG_MAX];
+    PMC* args_sig = pmc_new(interp, enum_class_FixedIntegerArray);
+    PMC* results_sig = pmc_new(interp, enum_class_FixedIntegerArray);
+    PMC* ret_cont = new_ret_continuation_pmc(interp, NULL);
+    parrot_context_t *ctx;
+    PMC* pccinvoke_meth;
+
+    opcode_t* save_current_args;
+    PMC* save_args_signature;
+    PMC* save_current_object;
+
+    /* temporary state vars for building PCC index and PCC signature arrays. */
+    opcode_t *indexes[2] = { arg_indexes, result_indexes };
+    PMC *sigs[2] = { args_sig, results_sig };
+    int arg_ret_cnt[2] = { 0, 0 }; /* # of arg args, # of result args */
+    int max_regs[8] = { 0, 0, 0, 0, 0, 0, 0, 0 }; /* INSP args, INSP results */
+    int seen_arrow = 0;
+    const char *x;
+    const char *ret_x;
+    int index = -1;
+    int cur = 0;
+
+    va_list list;
+    va_start(list, signature);
+
+    /* account for passing invocant in-band */
+    if (pmc) {
+        arg_ret_cnt[seen_arrow]++;
+        max_regs[REGNO_PMC]++;
+    }
+
+    /* first loop through signature to get sizing info */
+    for (x = signature; *x != '\0'; x++) {
+        /* detect -> separator */
+        if (*x == '-') {
+            seen_arrow = 1 ;
+        }
+        else if (isupper(*x)) {
+             /* calculate needed length of arg and result sig FIAs */
+            arg_ret_cnt[seen_arrow]++;
+            /* calculate max reg types (INSP) needed in context */
+            switch (*x) {
+                case 'I': max_regs[seen_arrow * 4 + REGNO_INT]++; break;
+                case 'N': max_regs[seen_arrow * 4 + REGNO_NUM]++; break;
+                case 'S': max_regs[seen_arrow * 4 + REGNO_STR]++; break;
+                case 'P': max_regs[seen_arrow * 4 + REGNO_PMC]++; break;
+                default:
+                          real_exception(interp, NULL, E_IndexError,
+                                  "Parrot_PCCINVOKE: invalid reg type %c!", *x);
+            }
+
+        }
+    }
+
+    /* calculate max reg types needed for both args and results */
+    n_regs_used[0] = MAX(max_regs[0], max_regs[4]);
+    n_regs_used[1] = MAX(max_regs[1], max_regs[5]);
+    n_regs_used[2] = MAX(max_regs[2], max_regs[6]);
+    n_regs_used[3] = MAX(max_regs[3], max_regs[7]);
+
+    /* initialize arg and return sig FIAs with collected info */
+    if (arg_ret_cnt[0] > 0)
+        VTABLE_set_integer_native(interp, args_sig, arg_ret_cnt[0]);
+    if (arg_ret_cnt[1] > 0)
+        VTABLE_set_integer_native(interp, results_sig, arg_ret_cnt[1]);
+    ctx = Parrot_push_context(interp, n_regs_used);
+
+    /* reset n_regs_used so they can be reused during arg index allocation step */
+    n_regs_used[0] = 0;
+    n_regs_used[1] = 0;
+    n_regs_used[2] = 0;
+    n_regs_used[3] = 0;
+
+
+    /* second loop through signature to build all index and arg_flag
+     * loop also assigns args(up to the ->) to registers */
+    index = -1;
+    seen_arrow = 0;
+
+    /* account for passing invocant in-band */
+    if (pmc) {
+        indexes[0][0] = 0;
+        VTABLE_set_integer_keyed_int(interp, sigs[0], 0, PARROT_ARG_PMC);
+        CTX_REG_PMC(ctx, 0) = pmc;
+        n_regs_used[seen_arrow * 4 + REGNO_PMC]++;
+        index = 0;
+    }
+
+    for (x = signature; *x != '\0'; x++) {
+        /* detect -> separator */
+        if (*x == '-') {
+            x++; /* skip '>' */
+            ret_x = x; /* allows us to jump directly to the result signature portion during
+                            results assignment */
+            ret_x++; /* save off pointer to results */
+
+            if (index >= 0) {
+              commit_last_arg(interp, index, cur, n_regs_used, seen_arrow, sigs, indexes, ctx,
+                      pmc, &list);
+            }
+
+            /* reset parsing state so we can now handle results */
+            seen_arrow = 1;
+            index = -1;
+            /* reset n_regs_used so they can be reused during result index allocation step */
+            n_regs_used[0] = 0;
+            n_regs_used[1] = 0;
+            n_regs_used[2] = 0;
+            n_regs_used[3] = 0;
+        }
+        /* parse arg type */
+        else if (isupper(*x)) {
+            if (index >= 0) {
+              commit_last_arg(interp, index, cur, n_regs_used, seen_arrow, sigs, indexes, ctx,
+                      pmc, &list);
+            }
+            index++;
+
+            switch (*x) {
+                case 'I': cur = PARROT_ARG_INTVAL; break;
+                case 'N': cur = PARROT_ARG_FLOATVAL; break;
+                case 'S': cur = PARROT_ARG_STRING; break;
+                case 'P': cur = PARROT_ARG_PMC; break;
+                default:
+                          real_exception(interp, NULL, E_IndexError,
+                                  "Parrot_PCCINVOKE: invalid reg type %c!", *x);
+            }
+
+        }
+        /* parse arg adverbs */
+        else if (islower(*x)) {
+            switch (*x) {
+                case 'n': cur |= PARROT_ARG_NAME; break;
+                case 'f': cur |= PARROT_ARG_FLATTEN; break;
+                case 's': cur |= PARROT_ARG_SLURPY_ARRAY; break;
+                case 'o': cur |= PARROT_ARG_OPTIONAL; break;
+                case 'p': cur |= PARROT_ARG_OPT_FLAG; break;
+                default:
+                          real_exception(interp, NULL, E_IndexError,
+                                  "Parrot_PCCINVOKE: invalid adverb type %c!", *x);
+            }
+        }
+    }
+    if (index >= 0) {
+        commit_last_arg(interp, index, cur, n_regs_used, seen_arrow, sigs, indexes, ctx,
+                pmc, &list);
+    }
+
+    /* code from PCCINVOKE impl in PCCMETHOD.pm */
+    save_current_args = interp->current_args;
+    save_args_signature = interp->args_signature;
+    save_current_object = interp->current_object;
+
+    interp->current_args = arg_indexes;
+    interp->args_signature = args_sig;
+    ctx->current_results = result_indexes;
+    ctx->results_signature = results_sig;
+
+
+    /* arg_accessors assigned in loop above */
+
+    interp->current_object = pmc;
+    interp->current_cont = NEED_CONTINUATION;
+    ctx->current_cont = ret_cont;
+    PMC_cont(ret_cont)->from_ctx = ctx;
+    pccinvoke_meth = VTABLE_find_method(interp, pmc, method_name);
+    if (!pccinvoke_meth) {
+        real_exception(interp, NULL, METH_NOT_FOUND, "Method '%Ss' not found", method_name);
+    }
+    else {
+        VTABLE_invoke(interp, pccinvoke_meth, NULL);
+    }
+
+    /* result_accessors, perform the arg accessor function,
+     * assigning the corresponding registers to the result variables */
+    index = 0;
+    seen_arrow = 1;
+    for (x=ret_x; *x != '\0'; x++) {
+        if (isupper(*x)) {
+            INTVAL *tmpINTVAL;
+            FLOATVAL *tmpFLOATVAL;
+            STRING **tmpSTRING;
+            PMC **tmpPMC;
+            switch (*x) {
+                case 'I':
+                    tmpINTVAL = va_arg(list, INTVAL*);
+                    *tmpINTVAL = CTX_REG_INT(ctx, indexes[seen_arrow][index]);
+                    break;
+                case 'N':
+                    tmpFLOATVAL = va_arg(list, FLOATVAL*);
+                    *tmpFLOATVAL = CTX_REG_NUM(ctx, indexes[seen_arrow][index]);
+                    break;
+                case 'S':
+                    tmpSTRING = va_arg(list, STRING**);
+                    *tmpSTRING = CTX_REG_STR(ctx, indexes[seen_arrow][index]);
+                    break;
+                case 'P':
+                    tmpPMC = va_arg(list, PMC**);
+                    *tmpPMC = CTX_REG_PMC(ctx, indexes[seen_arrow][index]);
+                    break;
+                default:
+                          real_exception(interp, NULL, E_IndexError,
+                                  "Parrot_PCCINVOKE: invalid reg type %c!", *x);
+            }
+        }
+    }
+
+    PObj_live_CLEAR(args_sig);
+    PObj_live_CLEAR(results_sig);
+    Parrot_pop_context(interp);
+    interp->current_args = save_current_args;
+    interp->args_signature = save_args_signature;
+    interp->current_object = save_current_object;
+}
+
+
 /*
 
 =back
