@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2003, The Perl Foundation.
-$Id: /parrot/offline/src/inter_create.c 3607 2007-01-14T02:22:13.469865Z coke  $
+$Id: inter_create.c 18183 2007-04-14 03:15:44Z chromatic $
 
 =head1 NAME
 
@@ -8,7 +8,7 @@ src/inter_create.c - Parrot Interpreter Creation and Destruction
 
 =head1 DESCRIPTION
 
-Create or destroy a Parrot interpreter.c
+Create or destroy a Parrot interpreter
 
 =head2 Functions
 
@@ -102,7 +102,7 @@ make_interpreter(Parrot_Interp parent, Interp_flags flags)
         interp = &interpre;
     else
 #endif
-        interp = mem_sys_allocate_zeroed(sizeof (Interp));
+        interp = mem_allocate_zeroed_typed(Interp);
 
     /*
      * the last interpreter (w/o) parent has to cleanup globals
@@ -123,7 +123,7 @@ make_interpreter(Parrot_Interp parent, Interp_flags flags)
     interp->resume_flag = RESUME_INITIAL;
     /* main is called as a Sub too - this will get depth 0 then */
     CONTEXT(interp->ctx)->recursion_depth = -1;
-    interp->recursion_limit = 1000;
+    interp->recursion_limit = RECURSION_LIMIT;
 
     /* Must initialize flags here so the GC_DEBUG stuff is available before
      * mem_setup_allocator() is called. */
@@ -175,10 +175,10 @@ make_interpreter(Parrot_Interp parent, Interp_flags flags)
     /* undefined globals are errors by default */
     PARROT_ERRORS_on(interp, PARROT_ERRORS_GLOBALS_FLAG);
     /* param count mismatch is an error by default */
-    PARROT_ERRORS_on(interp, PARROT_ERRORS_PARAM_COUNT_FLAG );
+    PARROT_ERRORS_on(interp, PARROT_ERRORS_PARAM_COUNT_FLAG);
 #if 0
     /* TODO not yet - too many test failures */
-    PARROT_ERRORS_on(interp, PARROT_ERRORS_RESULT_COUNT_FLAG );
+    PARROT_ERRORS_on(interp, PARROT_ERRORS_RESULT_COUNT_FLAG);
 #endif
 
     /* allocate stack chunk cache */
@@ -206,7 +206,7 @@ make_interpreter(Parrot_Interp parent, Interp_flags flags)
     SET_NULL_P(interp->evc_func_table, op_func_t *);
     SET_NULL_P(interp->save_func_table, op_func_t *);
 
-    SET_NULL_P(interp->code, struct PackFile *);
+    SET_NULL_P(interp->code, PackFile *);
     SET_NULL_P(interp->profile, ProfData *);
 
     /* null out the root set registry */
@@ -394,11 +394,11 @@ Parrot_really_destroy(Interp *interp, int exit_code, void *arg)
     mem_sys_free(interp->arena_base);
     interp->arena_base = NULL;
     /* cache structure */
-    mem_sys_free(interp->caches);
+    destroy_object_cache(interp);
     /* packfile */
 
     if (!Interp_flags_TEST(interp, PARROT_EXTERN_CODE_FLAG))  {
-        struct PackFile *pf = interp->initial_pf;
+        PackFile *pf = interp->initial_pf;
         if (pf)
             PackFile_destroy(interp, pf);
     }
@@ -425,6 +425,7 @@ Parrot_really_destroy(Interp *interp, int exit_code, void *arg)
 
     /* predefined exceptions */
     mem_sys_free(interp->exception_list);
+    destroy_exception_list(interp);
     if (interp->evc_func_table)
         mem_sys_free(interp->evc_func_table);
     /* strings, charsets, encodings - only once */
@@ -446,7 +447,7 @@ Parrot_really_destroy(Interp *interp, int exit_code, void *arg)
         if (!interp->thread_data || (
                     interp->thread_data &&
                     (interp->thread_data->state & THREAD_STATE_JOINED))) {
-            if (interp->thread_data ) {
+            if (interp->thread_data) {
                 mem_sys_free(interp->thread_data);
                 interp->thread_data = NULL;
             }
