@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2006, The Perl Foundation.
-$Id: /parrot/offline/src/inter_misc.c 4256 2007-03-03T01:16:13.129634Z coke  $
+$Id: inter_misc.c 18206 2007-04-14 20:50:06Z chromatic $
 
 =head1 NAME
 
@@ -35,31 +35,36 @@ class C<type>.
 =cut
 
 */
-void Parrot_NCI_make_raw_nci(Interp *interp, PMC *method, void *func);
+void Parrot_NCI_nci_make_raw_nci(Interp *interp, PMC *method, void *func);
 
 void
-enter_nci_method(Parrot_Interp interp, const int type, void *func, const char *name, const char *proto)
+enter_nci_method(Parrot_Interp interp, const int type, void *func,
+        const char *name, const char *proto)
 {
     PMC * const method = pmc_new(interp, enum_class_NCI);
     /* create call func */
     VTABLE_set_pointer_keyed_str(interp, method,
-            string_make(interp, proto, strlen(proto), NULL, PObj_constant_FLAG|PObj_external_FLAG),
+            string_make(interp, proto, strlen(proto), NULL,
+                PObj_constant_FLAG|PObj_external_FLAG),
             func);
     /* insert it into namespace */
     VTABLE_set_pmc_keyed_str(interp, interp->vtables[type]->_namespace,
-            string_make(interp, name, strlen(name), NULL, PObj_constant_FLAG|PObj_external_FLAG),
+            string_make(interp, name, strlen(name), NULL,
+                PObj_constant_FLAG|PObj_external_FLAG),
             method);
 }
 
 void
-register_raw_nci_method_in_ns(Parrot_Interp interp, const int type, void *func, const char *name)
+register_raw_nci_method_in_ns(Parrot_Interp interp, const int type, void *func,
+        const char *name)
 {
     PMC * const method = pmc_new(interp, enum_class_NCI);
     /* setup call func */
-    Parrot_NCI_make_raw_nci(interp, method, func);
+    Parrot_NCI_nci_make_raw_nci(interp, method, func);
     /* insert it into namespace */
     VTABLE_set_pmc_keyed_str(interp, interp->vtables[type]->_namespace,
-            string_make(interp, name, strlen(name), NULL, PObj_constant_FLAG|PObj_external_FLAG),
+            string_make(interp, name, strlen(name), NULL,
+                PObj_constant_FLAG|PObj_external_FLAG),
             method);
 }
 
@@ -208,7 +213,7 @@ interpinfo(Interp *interp, INTVAL what)
 {
     INTVAL ret = 0;
     int j;
-    struct Arenas *arena_base = interp->arena_base;
+    Arenas *arena_base = interp->arena_base;
 
     switch (what) {
         case TOTAL_MEM_ALLOC:
@@ -235,7 +240,7 @@ interpinfo(Interp *interp, INTVAL what)
         case ACTIVE_BUFFERS:
             ret = 0;
             for (j = 0; j < (INTVAL)arena_base->num_sized; j++) {
-                struct Small_Object_Pool * const header_pool =
+                Small_Object_Pool * const header_pool =
                     arena_base->sized_header_pools[j];
                 if (header_pool)
                     ret += header_pool->total_objects -
@@ -248,7 +253,7 @@ interpinfo(Interp *interp, INTVAL what)
         case TOTAL_BUFFERS:
             ret = 0;
             for (j = 0; j < (INTVAL)arena_base->num_sized; j++) {
-                struct Small_Object_Pool * const header_pool =
+                Small_Object_Pool * const header_pool =
                     arena_base->sized_header_pools[j];
                 if (header_pool)
                     ret += header_pool->total_objects;
