@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2003, The Perl Foundation.
-$Id: /parrot/offline/src/io/io.c 3842 2007-01-26T02:12:34.106993Z coke  $
+$Id: io.c 18187 2007-04-14 12:43:22Z jonathan $
 
 =head1 NAME
 
@@ -233,7 +233,7 @@ PIO_destroy(Interp *interp, PMC *pmc)
 #endif
     if ((io->stack->flags & PIO_L_LAYER_COPIED)) {
         ParrotIOLayer *p, *down;
-        for (p = io->stack; p; ) {
+        for (p = io->stack; p;) {
             /* if top got copied, all have to be malloced */
             assert(p->flags & PIO_L_LAYER_COPIED);
             down = p->down;
@@ -331,7 +331,7 @@ PIO_finish(Interp *interp)
      * destruction into two parts (again).
      */
     for (i = 0 ; i < PIO_NR_OPEN; i++) {
-        if ( (pmc = interp->piodata->table[i]) ) {
+        if ((pmc = interp->piodata->table[i])) {
             layer = PMC_struct_val(pmc);
             io = PMC_data(pmc);
             PIO_close_down(interp, layer, io);
@@ -341,7 +341,7 @@ PIO_finish(Interp *interp)
     /*
      * TODO free IO of std-handles
      */
-    for (layer = interp->piodata->default_stack; layer; ) {
+    for (layer = interp->piodata->default_stack; layer;) {
         down = layer->down;
         if (layer->api->Delete)
             (*layer->api->Delete) (layer);
@@ -1325,8 +1325,15 @@ microseconds.
 INTVAL
 PIO_poll(Interp *interp, PMC *pmc, INTVAL which, INTVAL sec, INTVAL usec)
 {
-    ParrotIOLayer * const l = PMC_struct_val(pmc);
-    ParrotIO * const io = PMC_data0(pmc);
+    ParrotIOLayer *l;
+    ParrotIO *io;
+
+    if (pmc == PMCNULL) {
+        real_exception(interp, NULL, E_ValueError, "Can't poll NULL pmc");
+    }
+
+    l = PMC_struct_val(pmc);
+    io = PMC_data0(pmc);
     return PIO_poll_down(interp, l, io, which, sec, usec);
 }
 
