@@ -3,7 +3,7 @@
  *
  * PPC
  *
- * $Id: /parrot/offline/src/jit/ppc/jit_emit.h 3522 2007-01-10T21:20:16.890082Z coke  $
+ * $Id: jit_emit.h 18183 2007-04-14 03:15:44Z chromatic $
  */
 
 #if !defined(PARROT_PPC_JIT_EMIT_H_GUARD)
@@ -661,13 +661,13 @@ jit_emit_bx(Parrot_jit_info_t *jit_info, char type, opcode_t disp)
 
 #  define jit_emit_load_op_map(pc) \
     jit_emit_lwz(pc, ISR1, offsetof(Interp, code), r16); \
-    jit_emit_lwz(pc, ISR1, offsetof(struct PackFile_ByteCode, jit_info), ISR1); \
+    jit_emit_lwz(pc, ISR1, offsetof(PackFile_ByteCode, jit_info), ISR1); \
     jit_emit_lwz(pc, r14, (offsetof(Parrot_jit_arena_t, op_map) + \
                            offsetof(Parrot_jit_info_t, arena)), ISR1)
 
 #  define jit_emit_load_code_start(pc) \
     jit_emit_lwz(pc, ISR1, offsetof(Interp, code), r16); \
-    jit_emit_lwz(pc, r15,  offsetof(struct PackFile_Segment, data), ISR1)
+    jit_emit_lwz(pc, r15,  offsetof(PackFile_Segment, data), ISR1)
 
 #  define jit_emit_branch_to_opcode(pc, D) \
     jit_emit_lwz(pc, r13, offsetof(Interp, ctx.bp), r16); \
@@ -832,7 +832,7 @@ Parrot_jit_cpcf_op(Parrot_jit_info_t *jit_info,
     jit_emit_branch_to_opcode(jit_info->native_ptr, r3);
 }
 
-static void Parrot_end_jit(Parrot_jit_info_t *, Interp * );
+static void Parrot_end_jit(Parrot_jit_info_t *, Interp *);
 
 #  undef Parrot_jit_restart_op
 /* Parrot_jit_restart_op is based on the i386 version */
@@ -961,7 +961,7 @@ jit_set_args_pc(Parrot_jit_info_t *jit_info, Interp * interpreter,
 {
     PMC *sig_args, *sig_params, *sig_result;
     INTVAL *sig_bits, sig, i, n;
-    struct PackFile_Constant ** constants;
+    PackFile_Constant ** constants;
     opcode_t *params, *result;
     char params_map;
     int skip, used_n;
@@ -1081,7 +1081,7 @@ Parrot_jit_begin(Parrot_jit_info_t *jit_info,
     jit_emit_mflr(jit_info->native_ptr, r0);
     jit_emit_stmw(jit_info->native_ptr, r13, -PPC_JIT_GP_REGISTER_SAVE_SPACE, r1);
 
-    for ( i = 1; i <= 18; ++i )
+    for (i = 1; i <= 18; ++i)
     {
         jit_emit_stfd(jit_info->native_ptr, (i + 13), (-PPC_JIT_GP_REGISTER_SAVE_SPACE - i*8), r1);
     }
@@ -1223,14 +1223,14 @@ jit_mov_mr_offs(Parrot_jit_info_t *jit_info, int base, INTVAL offs, int reg)
 static void
 jit_mov_rm_offs(Parrot_jit_info_t *jit_info, int reg, int base, INTVAL offs)
 {
-    jit_emit_mov_rm_i( jit_info->native_ptr, reg, offs);
+    jit_emit_mov_rm_i(jit_info->native_ptr, reg, offs);
 }
 
 /* move reg to mem (i.e. numreg) */
 static void
 jit_mov_mr_n_offs(Parrot_jit_info_t * jit_info, int base, INTVAL offs, int reg)
 {
-    jit_emit_mov_mr_n( jit_info->native_ptr, offs, reg);
+    jit_emit_mov_mr_n(jit_info->native_ptr, offs, reg);
     jit_info->prev_op = 0;
 }
 
@@ -1306,8 +1306,7 @@ ppc_flush_line(char *_sync)
     __asm__ __volatile__ (
     "dcbf 0,%0"
     :
-    : "r" ((long)_sync)
-    );
+    : "r" ((long)_sync));
 }
 
 void
