@@ -3,7 +3,7 @@
 **
 ** SPARC
 **
-** $Id: /parrot/offline/src/jit/sun4/jit_emit.h 3225 2006-12-29T03:28:40.817280Z coke  $
+** $Id: jit_emit.h 18216 2007-04-15 03:31:19Z chromatic $
 **/
 
 #if !defined(PARROT_SUN4_JIT_EMIT_H_GUARD)
@@ -370,14 +370,14 @@ enum  {JIT_BRANCH, JIT_CALL30 };
 /* Load op_map address */
 #  define jit_emit_load_op_map(pc, code) \
     emitm_ld_i(jit_info->native_ptr, code,                                         \
-        offsetof(struct PackFile_ByteCode, jit_info), XSR1);                       \
+        offsetof(PackFile_ByteCode, jit_info), XSR1);                       \
     emitm_ld_i(jit_info->native_ptr, XSR1,                                         \
       (offsetof(Parrot_jit_arena_t, op_map) + offsetof(Parrot_jit_info_t, arena)), \
       Parrot_jit_opmap);
 
 /* Construct the starting address of the byte code (code start) */
 #  define jit_emit_load_code_start(pc, code) \
-    emitm_ld_i(jit_info->native_ptr, code, offsetof(struct PackFile_Segment, data), \
+    emitm_ld_i(jit_info->native_ptr, code, offsetof(PackFile_Segment, data), \
                XSR1);
 
 /* Generate a jump to a bytecode address in reg_num
@@ -849,7 +849,7 @@ Parrot_jit_vtable_n_op(Parrot_jit_info_t *jit_info,
     int    idx, pi, i;
     size_t offset;
 
-    offset  = offsetof(struct _vtable, init);
+    offset  = offsetof(VTABLE, init);
     offset += nvtable * sizeof (void *);
 
     for (idx = 1; idx <= n; idx++) {
@@ -1107,7 +1107,7 @@ Parrot_jit_vtable_newp_ic_op(Parrot_jit_info_t *jit_info,
                      Interp *interp)
 {
     void *igniter = (void (*)(void))pmc_new_noinit;
-    size_t offset = offsetof(struct _vtable, init);
+    size_t offset = offsetof(VTABLE, init);
 
     int p1 = *(jit_info->cur_op + 1);
     int i2 = *(jit_info->cur_op + 2);
