@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2006, The Perl Foundation.
-$Id: /parrot/offline/src/jit_debug_xcoff.c 3522 2007-01-10T21:20:16.890082Z coke  $
+$Id: jit_debug_xcoff.c 17912 2007-03-31 22:07:50Z paultcochrane $
 
 =head1 NAME
 
@@ -127,8 +127,7 @@ write_types(FILE *stabs, Interp *interp)
                 BIT_OFFSET(STRING, obj.u._b._buflen), BIT_SIZE(size_t),
                 BIT_OFFSET(STRING, obj.flags), BIT_SIZE(UINTVAL),
                 BIT_OFFSET(STRING, bufused), BIT_SIZE(UINTVAL),
-                BIT_OFFSET(STRING, strstart), BIT_SIZE(void*)
-                );
+                BIT_OFFSET(STRING, strstart), BIT_SIZE(void*));
 
     fprintf(stabs, ".stabx \"PMCType:T%d=e", i++);
     for (j = 0; j < interp->n_vtable_max; ++j) {
@@ -161,22 +160,19 @@ write_types(FILE *stabs, Interp *interp)
                 ";\""
                 ",0," C_DECL ",0\n", i + 1, (int)(sizeof (pobj_t)),
                 i + 2, BIT_OFFSET(pobj_t, u), BIT_SIZE(UnionVal),
-                BIT_OFFSET(pobj_t, flags), BIT_SIZE(Parrot_UInt)
-                );
+                BIT_OFFSET(pobj_t, flags), BIT_SIZE(Parrot_UInt));
     fprintf(stabs, ".stabx \"UnionVal:T%d=u%d"
                 "int_val:12,%d,%d;"
                 "pmc_val:*%d,%d,%d;"
                 ";\""
                 ",0," C_DECL ",0\n", i + 2, BYTE_SIZE(UnionVal),
                 BIT_OFFSET(UnionVal, int_val), BIT_SIZE(INTVAL),
-                i, BIT_OFFSET(UnionVal, pmc_val), BIT_SIZE(void*)
-                );
+                i, BIT_OFFSET(UnionVal, pmc_val), BIT_SIZE(void*));
     fprintf(stabs, ".stabx \"VTABLE:T%d=s%d"
                 "base_type:%d,%d,%d;"
                 ";\""
                 ",0," C_DECL ",0\n", i + 3, BYTE_SIZE(UnionVal),
-                i - 1, BIT_OFFSET(VTABLE, base_type), BIT_SIZE(INTVAL)
-                );
+                i - 1, BIT_OFFSET(VTABLE, base_type), BIT_SIZE(INTVAL));
     i += 4;
 
 }
@@ -296,12 +292,12 @@ Parrot_jit_debug_stabs(Interp *interp)
         free(temp);
     }
     /* declare function name */
-    fprintf(stabs, ".jit_func:\n" );
+    fprintf(stabs, ".jit_func:\n");
     /* jit_func start addr */
     fprintf(stabs, ".stabx \"jit_func:F1\",0x%p," C_FUN ",0\n",
             jit_info->arena.start);
-    fprintf(stabs, ".function .jit_func,.jit_func,0,0\n" );
-    fprintf(stabs, ".bf 1\n" );
+    fprintf(stabs, ".function .jit_func,.jit_func,0,0\n");
+    fprintf(stabs, ".bf 1\n");
 
     write_types(stabs, interp);
     write_vars(stabs, interp);
