@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2004, The Perl Foundation.
-$Id: /parrot/offline/src/library.c 4627 2007-03-19T17:22:35.116794Z coke  $
+$Id: library.c 18134 2007-04-11 06:36:43Z chromatic $
 
 =head1 NAME
 
@@ -160,30 +160,30 @@ is_abs_path(Interp* interp, STRING *file)
     return 0;
 }
 
-static const char path_seperator = '/';
+static const char path_separator = '/';
 
 #ifdef WIN32
 
-static const char win32_path_seperator = '\\';
+static const char win32_path_separator = '\\';
 
 /*
    Converts a path with forward slashes to one with backward slashes.
 */
 static void
-cnv_to_win32_filesep ( STRING *path ) {
+cnv_to_win32_filesep (STRING *path) {
     char* cnv;
 
     assert(path->encoding == Parrot_fixed_8_encoding_ptr ||
         path->encoding == Parrot_utf8_encoding_ptr);
 
-    while (cnv = strchr(path->strstart, path_seperator))
-        *cnv = win32_path_seperator;
+    while ((cnv = strchr(path->strstart, path_separator)) != NULL)
+        *cnv = win32_path_separator;
 }
 
 #endif
 
 static STRING*
-path_finalize(Interp *interp, STRING *path )
+path_finalize(Interp *interp, STRING *path)
 {
 
     /* TODO create a string API that just does that
@@ -198,59 +198,59 @@ path_finalize(Interp *interp, STRING *path )
     path->strlen--;
 
 #ifdef WIN32
-    cnv_to_win32_filesep( path );
+    cnv_to_win32_filesep(path);
 #endif
 
     return path;
 }
 
 /*
-  unary path arguement. the path string will have a
-  trailing path-seperator appended if it is not
+  unary path argument. the path string will have a
+  trailing path-separator appended if it is not
   there already.
  */
 
 static STRING*
-path_garuntee_trailing_seperator(Interp *interp, STRING *path )
+path_guarantee_trailing_separator(Interp *interp, STRING *path)
 {
-    STRING *path_seperator_string = string_chr(interp, path_seperator);
+    STRING *path_separator_string = string_chr(interp, path_separator);
 
     /* make sure the path has a trailing slash before appending the file */
-    if ( string_index(interp, path , path->strlen - 1)
-         != string_index(interp, path_seperator_string, 0))
-        path = string_append(interp, path , path_seperator_string);
+    if (string_index(interp, path , path->strlen - 1)
+         != string_index(interp, path_separator_string, 0))
+        path = string_append(interp, path , path_separator_string);
 
     return path;
 }
 
 /*
-  binary path arguements, the left arg is modified.
-  a trailing seperator is garunteed for the left
-  arguement and the right arguement is appended
+  binary path arguments, the left arg is modified.
+  a trailing separator is guaranteed for the left
+  argument and the right argument is appended
  */
 
 static STRING*
-path_append(Interp *interp, STRING *l_path, STRING *r_path )
+path_append(Interp *interp, STRING *l_path, STRING *r_path)
 {
-    l_path = path_garuntee_trailing_seperator(interp, l_path );
+    l_path = path_guarantee_trailing_separator(interp, l_path);
     l_path = string_append(interp, l_path , r_path);
 
     return l_path;
 }
 
 /*
-  binary path arguements. A new sting is created
+  binary path arguments. A new string is created
   that is the concatentation of the two path components
-  with a path-seperator.
+  with a path-separator.
  */
 
 static STRING*
-path_concat(Interp *interp, STRING *l_path, STRING *r_path )
+path_concat(Interp *interp, STRING *l_path, STRING *r_path)
 {
     STRING* join;
 
     join = string_copy(interp, l_path);
-    join = path_garuntee_trailing_seperator(interp, join );
+    join = path_guarantee_trailing_separator(interp, join);
     join = string_append(interp, join , r_path);
 
     return join;
@@ -305,20 +305,20 @@ Parrot_locate_runtime_file_str(Interp *interp, STRING *file,
         path = VTABLE_get_string_keyed_int(interp, paths, i);
         if (string_length(interp, prefix) &&
            !is_abs_path(interp,path)) {
-            full_name = path_concat(interp, prefix , path );
+            full_name = path_concat(interp, prefix , path);
         }
         else
             full_name = string_copy(interp, path);
 
-        full_name = path_append(interp, full_name , file );
+        full_name = path_append(interp, full_name , file);
 
-        full_name = path_finalize(interp, full_name );
+        full_name = path_finalize(interp, full_name);
         if (Parrot_stat_info_intval(interp, full_name, STAT_EXISTS)) {
             return full_name;
         }
     }
 
-    full_name = path_finalize( interp, file );
+    full_name = path_finalize(interp, file);
     if (Parrot_stat_info_intval(interp, full_name, STAT_EXISTS)) {
         return full_name;
     }
@@ -427,12 +427,12 @@ parrot_split_path_ext(Interp* interp, STRING *in,
     pos_dot = CHARSET_RINDEX(interp, in, dot, len);
 
     /* XXX directory parrot-0.4.1 or such */
-    if (pos_dot != -1 && isdigit( ((char*)in->strstart)[pos_dot+1]))
+    if (pos_dot != -1 && isdigit(((char*)in->strstart)[pos_dot+1]))
         pos_dot = -1;
 
     ++pos_dot;
     ++pos_sl;
-    if (pos_sl && pos_dot ) {
+    if (pos_sl && pos_dot) {
         stem = string_substr(interp, in, pos_sl, pos_dot - pos_sl - 1,
                 NULL, 0);
         *wo_ext = string_substr(interp, in, 0, pos_dot - 1, NULL, 0);
