@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2003-2006, The Perl Foundation.
-$Id: /parrot/offline/src/mmd.c 3607 2007-01-14T02:22:13.469865Z coke  $
+$Id: mmd.c 18183 2007-04-14 03:15:44Z chromatic $
 
 =head1 NAME
 
@@ -782,7 +782,7 @@ mmd_register_sub(Interp *interp,
              PMC *sub)
 {
     PMC *fake;
-    if (sub->vtable->base_type == enum_class_CSub) {
+    if (sub->vtable->base_type == enum_class_NCI) {
         /* returned from mmdvt_find */
         mmd_register(interp, func_nr, left_type, right_type,
                 D2FPTR(PMC_struct_val(sub)));
@@ -826,9 +826,8 @@ mmd_destroy(Parrot_Interp interp)
 mmd_vtfind(Parrot_Interp interp, INTVAL type, INTVAL left, INTVAL right)>
 
 Return an MMD PMC function for the given data types. The return result is
-either a Sub PMC (for PASM MMD functions) or a CSub PMC holding the
-C function pointer in PMC_struct_val. This CSub is not invocable, you have to
-wrap it into an NCI function to get the required function arguments passed.
+either a Sub PMC (for PASM MMD functions) or a NCI PMC holding the
+C function pointer in PMC_struct_val.
 
 =cut
 
@@ -847,7 +846,7 @@ mmd_vtfind(Parrot_Interp interp, INTVAL func_nr,
          */
         return (PMC*)F2DPTR(func);
     }
-    f = pmc_new(interp, enum_class_CSub);
+    f = pmc_new(interp, enum_class_NCI);
     PMC_struct_val(f) = F2DPTR(func);
     return f;
 }
@@ -978,7 +977,7 @@ mmd_arg_tuple_func(Interp *interp)
     PMC* arg_tuple, *arg;
     PMC* args_array;    /* from recent set_args opcode */
     opcode_t *args_op;
-    struct PackFile_Constant **constants;
+    PackFile_Constant **constants;
 
     /*
      * if there is no signature e.g. because of
@@ -1177,7 +1176,7 @@ distance_cmp(Interp *interp, INTVAL a, INTVAL b)
     return da > db ? 1 : da < db ? -1 : 0;
 }
 
-extern void Parrot_FixedPMCArray_sort(Interp* , PMC* pmc, PMC *cmp_func);
+extern void Parrot_FixedPMCArray_nci_sort(Interp* , PMC* pmc, PMC *cmp_func);
 
 /*
 
@@ -1360,7 +1359,7 @@ mmd_sort_candidates(Interp *interp, PMC *arg_tuple, PMC *cl)
     /*
      * sort it
      */
-    Parrot_FixedPMCArray_sort(interp, sort, nci);
+    Parrot_FixedPMCArray_nci_sort(interp, sort, nci);
     /*
      * now helper has a sorted list of indices in the upper 16 bits
      * fill helper with sorted candidates
