@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2003, The Perl Foundation.
-$Id: /parrot/offline/src/objects.c 4173 2007-02-24T13:35:00.108264Z coke  $
+$Id: objects.c 18185 2007-04-14 03:54:14Z chromatic $
 
 =head1 NAME
 
@@ -42,7 +42,7 @@ Parrot_get_vtable_index(Interp *interp, const char *name)
 {
     int i;
     const char *meth;
-    for (i = 0; (meth = Parrot_vtable_slot_names[i]); ++i) {
+    for (i = 0; (meth = Parrot_vtable_slot_names[i]) != NULL; ++i) {
         if (!*meth)
             continue;
         /* XXX slot_names still have __ in front */
@@ -83,7 +83,9 @@ Parrot_find_vtable_meth(Interp* interp, PMC *pmc, STRING *meth) {
             key = VTABLE_nextkey_keyed(interp, key_new(interp), ns,
                 ITERATE_FROM_START);
             for (j = 0; j < k; ++j) {
-                STRING *ns_key = parrot_hash_get_idx(interp, PMC_struct_val(ns), key);
+                STRING *ns_key =
+                    (STRING *)parrot_hash_get_idx(interp,
+                        (Hash *)PMC_struct_val(ns), key);
                 PMC *res = VTABLE_get_pmc_keyed_str(interp, ns, ns_key);
                 if (res->vtable->base_type == enum_class_Sub &&
                         PMC_sub(res)->vtable_index == vtable_index)
@@ -120,8 +122,8 @@ fail_if_exist(Interp *interp, PMC *name)
     INTVAL type;
 
     PMC * const classname_hash = interp->class_hash;
-    PMC * type_pmc = VTABLE_get_pointer_keyed(interp,
-            classname_hash, name);
+    PMC * type_pmc             = (PMC *)VTABLE_get_pointer_keyed(interp,
+                                        classname_hash, name);
     if (PMC_IS_NULL(type_pmc) ||
             type_pmc->vtable->base_type == enum_class_NameSpace)
         type = 0;
@@ -183,12 +185,12 @@ rebuild_attrib_stuff(Interp *interp, PMC *class)
     PMC * const orig_class = class;
 #endif
 
-    /* attrib count isn't set yet, a GC causedd by concat could
+    /* attrib count isn't set yet, a GC caused by concat could
      * corrupt data under construction
      */
     Parrot_block_DOD(interp);
 
-    class_slots = PMC_data(class);
+    class_slots      = PMC_data_typed(class, SLOTTYPE *);
     attr_offset_hash = pmc_new(interp, enum_class_Hash);
     set_attrib_num(class, class_slots, PCD_ATTRIBUTES, attr_offset_hash);
 
@@ -207,8 +209,8 @@ rebuild_attrib_stuff(Interp *interp, PMC *class)
             continue;
         }
 
-        class_slots = PMC_data(class);
-        classname = VTABLE_get_string(interp,
+        class_slots = PMC_data_typed(class, SLOTTYPE *);
+        classname   = VTABLE_get_string(interp,
                     get_attrib_num(class_slots, PCD_CLASS_NAME));
         attribs = get_attrib_num(class_slots, PCD_CLASS_ATTRIBUTES);
         attr_count = VTABLE_elements(interp, attribs);
@@ -297,7 +299,8 @@ create_deleg_pmc_vtable(Interp *interp, PMC *class,
 
     PMC * const vtable_pmc = get_attrib_num((SLOTTYPE*)PMC_data(class),
                                             PCD_OBJECT_VTABLE);
-    VTABLE * const vtable           = PMC_struct_val(vtable_pmc);
+    VTABLE * const vtable           =
+        (VTABLE * const)PMC_struct_val(vtable_pmc);
     VTABLE * const ro_vtable        = vtable->ro_variant_vtable;
     VTABLE * const deleg_pmc_vtable =
         interp->vtables[enum_class_deleg_pmc];
@@ -309,7 +312,7 @@ create_deleg_pmc_vtable(Interp *interp, PMC *class,
     memset(&meth_str, 0, sizeof (meth_str));
     meth_str.encoding = Parrot_fixed_8_encoding_ptr;
     meth_str.charset = Parrot_default_charset_ptr;
-    for (i = 0; (meth = Parrot_vtable_slot_names[i]); ++i) {
+    for (i = 0; (meth = Parrot_vtable_slot_names[i]) != NULL; ++i) {
         if (!*meth)
             continue;
         meth_str.strstart = const_cast(meth);
@@ -421,7 +424,7 @@ Parrot_single_subclass(Interp *interp, PMC *base_class,
         STRING *child_class_name = Parrot_sprintf_c(interp,
                 "%c%canon_%d", 0, 0, ++anon_count);
         name = pmc_new(interp, enum_class_String);
-        VTABLE_set_string_native(interp, name, child_class_name );
+        VTABLE_set_string_native(interp, name, child_class_name);
     }
     /*
      * ParrotClass is the baseclass anyway, so build just a new class
@@ -432,10 +435,12 @@ Parrot_single_subclass(Interp *interp, PMC *base_class,
     parent_is_class = PObj_is_class_TEST(base_class);
 
     child_class = pmc_new(interp, enum_class_ParrotClass);
+
     /* Hang an array off the data pointer */
     set_attrib_array_size(child_class, PCD_MAX);
-    child_class_array = PMC_data(child_class);
+    child_class_array = PMC_data_typed(child_class, SLOTTYPE *);
     set_attrib_flags(child_class);
+
     /* We will have five entries in this array */
 
     /* We have the same number of attributes as our parent */
@@ -524,7 +529,7 @@ Parrot_new_class(Interp *interp, PMC *class, PMC *name)
 
     /* Hang an array off the data pointer, empty of course */
     set_attrib_array_size(class, PCD_MAX);
-    class_array = PMC_data(class);
+    class_array = PMC_data_typed(class, SLOTTYPE *);
     /* set_attrib_flags(class); init does it */
 
     /* Our parent class array has nothing in it */
@@ -700,9 +705,9 @@ parrot_class_register(Interp *interp, PMC *name,
      * a ParrotObject vtable
      */
     if (parent && PObj_is_class_TEST(parent)) {
-        vtable_pmc =
-            get_attrib_num((SLOTTYPE*)PMC_data(parent), PCD_OBJECT_VTABLE);
-        parent_vtable = PMC_struct_val(vtable_pmc);
+        vtable_pmc    =
+            get_attrib_num((SLOTTYPE *)PMC_data(parent), PCD_OBJECT_VTABLE);
+        parent_vtable = (VTABLE *)PMC_struct_val(vtable_pmc);
     }
     else
         parent_vtable = interp->vtables[enum_class_ParrotObject];
@@ -746,7 +751,8 @@ get_init_meth(Interp *interp, PMC *class,
         return NULL;
     meth = VTABLE_get_string(interp, prop);
 #else
-    if ( !(props = PMC_metadata(class)))
+    props = PMC_metadata(class);
+    if (!props)
         return NULL;
     b = parrot_hash_get_bucket(interp,
                 (Hash*) PMC_struct_val(props), prop_str);
@@ -814,9 +820,9 @@ do_initcall(Interp *interp, PMC* class, PMC *object, PMC *init)
             if (!PObj_is_class_TEST(next_parent)) {
                 continue;
             }
-            attr = pmc_new_noinit(interp,
+            attr     = pmc_new_noinit(interp,
                     parent_class->vtable->base_type);
-            obj_data = PMC_data(object);
+            obj_data = PMC_data_typed(object, SLOTTYPE *);
             set_attrib_num(object, obj_data, 0, attr);
             VTABLE_init(interp, attr);
             continue;
@@ -905,7 +911,7 @@ instantiate_object(Interp *interp, PMC *object, PMC *init)
      */
     PMC * const vtable_pmc = get_attrib_num((SLOTTYPE *)PMC_data(class),
                                             PCD_OBJECT_VTABLE);
-    object->vtable = PMC_struct_val(vtable_pmc);
+    object->vtable         = (VTABLE *)PMC_struct_val(vtable_pmc);
 
     /* Grab the attribute count from the class */
     attrib_count = CLASS_ATTRIB_COUNT(class);
@@ -913,7 +919,7 @@ instantiate_object(Interp *interp, PMC *object, PMC *init)
     /* Build the array that hangs off the new object */
     /* First presize it */
     set_attrib_array_size(object, attrib_count);
-    new_object_array = PMC_data(object);
+    new_object_array = PMC_data_typed(object, SLOTTYPE *);
 
     /* fill with PMCNULL, so that access doesn't segfault */
     for (i = 0; i < attrib_count; ++i)
@@ -1181,7 +1187,7 @@ interpreter, and name of the method. Don't use a possible method cache.
 
 =item void Parrot_invalidate_method_cache(Interp *, STRING *class)
 
-Clear method cache for the given class. If class is NULL caches for
+Clear method cache for the given class. If class is NULL, caches for
 all classes are invalidated.
 
 =cut
@@ -1198,11 +1204,24 @@ mark_object_cache(Interp *interp)
 void
 init_object_cache(Interp *interp)
 {
-    Caches * const mc = interp->caches =
-        mem_sys_allocate_zeroed(sizeof (*mc));
+    Caches * const mc = interp->caches = mem_allocate_zeroed_typed(Caches);
     SET_NULL(mc->idx);
 }
 
+void
+destroy_object_cache(Interp *interp)
+{
+    UINTVAL i;
+    Caches * const mc = interp->caches;
+
+    for (i = 0; i < mc->mc_size; i++) {
+        if (mc->idx[i])
+            mem_sys_free(mc->idx[i]);
+    }
+    mem_sys_free(mc->idx);
+    mem_sys_free(mc);
+}
+
 #define TBL_SIZE_MASK 0x1ff   /* x bits 2..10 */
 #define TBL_SIZE (1 + TBL_SIZE_MASK)
 
@@ -1219,7 +1238,7 @@ invalidate_type_caches(Interp *interp, UINTVAL type)
         return;
     for (i = 0; i < TBL_SIZE; ++i) {
         Meth_cache_entry *e;
-        for (e = mc->idx[type][i]; e; ) {
+        for (e = mc->idx[type][i]; e;) {
             Meth_cache_entry * const next = e->next;
             mem_sys_free(e);
             e = next;
@@ -1298,20 +1317,24 @@ Parrot_find_method_with_cache(Interp *interp, PMC *class,
     }
     mc = interp->caches;
     type = class->vtable->base_type;
-    bits = (((UINTVAL) method_name->strstart ) >> 2) & TBL_SIZE_MASK;
+    bits = (((UINTVAL) method_name->strstart) >> 2) & TBL_SIZE_MASK;
     if (type >= mc->mc_size) {
         if (mc->idx) {
-            mc->idx = mem_sys_realloc(mc->idx, sizeof (UINTVAL*) * (type + 1));
+            mc->idx = (Meth_cache_entry ***)mem_sys_realloc(mc->idx,
+                sizeof (Meth_cache_entry ***) * (type + 1));
         }
         else {
-            mc->idx = mem_sys_allocate(sizeof (UINTVAL*) * (type + 1));
+            mc->idx = (Meth_cache_entry ***)mem_sys_allocate(
+                sizeof (Meth_cache_entry ***) * (type + 1));
         }
         for (i = mc->mc_size; i <= type; ++i)
             mc->idx[i] = NULL;
         mc->mc_size = type + 1;
     }
     if (!mc->idx[type]) {
-        mc->idx[type] = mem_sys_allocate(sizeof (Meth_cache_entry*) * TBL_SIZE);
+        mc->idx[type] = (Meth_cache_entry **)mem_sys_allocate(
+            sizeof (Meth_cache_entry *) * TBL_SIZE);
+
         for (i = 0; i < TBL_SIZE; ++i)
             mc->idx[type][i] = NULL;
     }
@@ -1324,7 +1347,7 @@ Parrot_find_method_with_cache(Interp *interp, PMC *class,
     if (!e) {
         PMC * const found = find_method_direct(interp, class, method_name);
         /* when here no or no correct entry was at [bits] */
-        e = mem_sys_allocate(sizeof (Meth_cache_entry));
+        e = mem_allocate_typed(Meth_cache_entry);
         if (old)
             old->next = e;
         else
@@ -1350,7 +1373,7 @@ debug_trace_find_meth(Interp *interp, PMC *class, STRING *name, PMC *sub)
     if (!Interp_trace_TEST(interp, PARROT_TRACE_FIND_METH_FLAG))
         return;
     if (PObj_is_class_TEST(class)) {
-        SLOTTYPE * const class_array = PMC_data(class);
+        SLOTTYPE * const class_array = PMC_data_typed(class, SLOTTYPE *);
         PMC *const class_name_pmc = get_attrib_num(class_array, PCD_CLASS_NAME);
         class_name = PMC_str_val(class_name_pmc);
     }
@@ -1505,7 +1528,7 @@ Parrot_get_attrib_by_num(Interp *interp, PMC *object, INTVAL attrib)
      * their is no need for checking object being a valid
      * object PMC
      */
-    SLOTTYPE * const attrib_array = PMC_data(object);
+    SLOTTYPE * const attrib_array = PMC_data_typed(object, SLOTTYPE *);
     const INTVAL attrib_count = PMC_int_val(object);
 
     if (attrib >= attrib_count || attrib < 0) {
@@ -1599,7 +1622,7 @@ void
 Parrot_set_attrib_by_num(Interp *interp, PMC *object,
         INTVAL attrib, PMC *value)
 {
-    SLOTTYPE * const attrib_array = PMC_data(object);
+    SLOTTYPE * const attrib_array = PMC_data_typed(object, SLOTTYPE *);
     const INTVAL attrib_count = PMC_int_val(object);
 
     if (attrib >= attrib_count || attrib < 0) {
@@ -1695,6 +1718,308 @@ void Parrot_set_class_fallback(Interp *interp, STRING *class,
 {
 }
 
+
+/* ************************************************************************ */
+/* ********* BELOW HERE IS NEW PPD15 IMPLEMENTATION RELATED STUFF ********* */
+/* ************************************************************************ */
+
+/*
+
+=item C<PMC* Parrot_ComputeMRO_C3(Interp *interp, PMC *class)>
+
+Computes the C3 linearization for the given class.
+
+=cut
+
+*/
+
+static PMC* C3_merge(Interp *interp, PMC *merge_list)
+{
+    PMC *result = pmc_new(interp, enum_class_ResizablePMCArray);
+    int list_count = VTABLE_elements(interp, merge_list);
+    int cand_count = 0;
+    int i;
+    PMC *accepted = PMCNULL;
+
+    /* Try and find something appropriate to add to the MRO - basically, the
+     * first list head that is not in the tail of all the other lists. */
+    for (i = 0; i < list_count; i++) {
+        PMC *cand_list = VTABLE_get_pmc_keyed_int(interp, merge_list, i);
+        PMC *cand_class;
+        int reject = 0;
+        int j;
+        if (VTABLE_elements(interp, cand_list) == 0)
+            continue;
+        cand_class = VTABLE_get_pmc_keyed_int(interp, cand_list, 0);
+        cand_count++;
+        for (j = 0; j < list_count; j++) {
+            /* Skip the current list. */
+            if (j != i) {
+                /* Is it in the tail? If so, reject. */
+                PMC *check_list = VTABLE_get_pmc_keyed_int(interp, merge_list, j);
+                int check_length = VTABLE_elements(interp, check_list);
+                int k;
+
+                for (k = 1; k < check_length; k++) {
+                    if (VTABLE_get_pmc_keyed_int(interp, check_list, k) == cand_class) {
+                        reject = 1;
+                        break;
+                    }
+                }
+            }
+        }
+
+        /* If we didn't reject it, this candidate will do. */
+        if (!reject) {
+            accepted = cand_class;
+            break;
+        }
+    }
+
+    /* If we never found any candidates, return an empty list. */
+    if (cand_count == 0)
+        return pmc_new(interp, enum_class_ResizablePMCArray);
+
+    /* If we didn't find anything to accept, error. */
+    if (PMC_IS_NULL(accepted)) {
+        real_exception(interp, NULL, ILL_INHERIT,
+            "Could not build C3 linearization: ambiguous hierarchy");
+        return PMCNULL;
+    }
+
+    /* Otherwise, remove what was accepted from the merge lists. */
+    for (i = 0; i < list_count; i++) {
+        PMC *list = VTABLE_get_pmc_keyed_int(interp, merge_list, i);
+        int list_count = VTABLE_elements(interp, list);
+        int j;
+        for (j = 0; j < list_count; j++) {
+            if (VTABLE_get_pmc_keyed_int(interp, list, j) == accepted) {
+                VTABLE_delete_keyed_int(interp, list, j);
+                break;
+            }
+        }
+    }
+
+    /* Need to merge what remains of the list, then put what was accepted on
+     * the start of the list, and we're done. */
+    result = C3_merge(interp, merge_list);
+    VTABLE_unshift_pmc(interp, result, accepted);
+    return result;
+}
+
+PMC* Parrot_ComputeMRO_C3(Interp *interp, PMC *class)
+{
+    PMC *result;
+    PMC *merge_list = pmc_new(interp, enum_class_ResizablePMCArray);
+    PMC *immediate_parents;
+    int i, parent_count;
+
+    /* Now get immediate parents list. */
+    Parrot_PCCINVOKE(interp, class, string_from_const_cstring(interp, "parents", 0),
+        "->P", &immediate_parents);
+    if (immediate_parents == NULL) {
+        real_exception(interp, NULL, METH_NOT_FOUND,
+            "Failed to get parents list from class!");
+        return PMCNULL;
+    }
+    parent_count = VTABLE_elements(interp, immediate_parents);
+    if (parent_count == 0)
+    {
+        /* No parents - MRO just contains this class. */
+        result = pmc_new(interp, enum_class_ResizablePMCArray);
+        VTABLE_push_pmc(interp, result, class);
+        return result;
+    }
+
+    /* Otherwise, need to do merge. For that, need linearizations of all of
+     * our parents added to the merge list. */
+    for (i = 0; i < parent_count; i++) {
+        PMC *lin = Parrot_ComputeMRO_C3(interp,
+            VTABLE_get_pmc_keyed_int(interp, immediate_parents, i));
+        if (PMC_IS_NULL(lin))
+            return PMCNULL;
+        VTABLE_push_pmc(interp, merge_list, lin);
+    }
+
+    /* Finally, need list of direct parents on the end of the merge list, then
+     * we can merge. */
+    VTABLE_push_pmc(interp, merge_list, immediate_parents);
+    result = C3_merge(interp, merge_list);
+    if (PMC_IS_NULL(result))
+        return PMCNULL;
+
+    /* Merged result needs this class on the start, and then we're done. */
+    VTABLE_unshift_pmc(interp, result, class);
+    return result;
+}
+
+
+/*
+
+=item C<void Parrot_ComposeRole(Interp *interp, PMC *role,
+                        PMC *exclude, int got_exclude,
+                        PMC *alias, int got_alias,
+                        PMC *methods_hash, PMC *roles_list)>
+
+Used by the Class and Object PMCs internally to compose a role into either of
+them. The C<role> parameter is the role that we are composing into the class
+or role. C<methods_hash> is the hash of method names to invokable PMCs that
+contains the methods the class or role has. C<roles_list> is the list of roles
+the the class or method does.
+
+The C<role> parameter is only dealt with by its external interface. Whether
+this routine is usable by any other object system implemented in Parrot very
+much depends on how closely the role composition semantics they want are to
+the default implementation.
+
+=cut
+
+*/
+
+void Parrot_ComposeRole(Interp *interp, PMC *role,
+                        PMC *exclude, int got_exclude,
+                        PMC *alias, int got_alias,
+                        PMC *methods_hash, PMC *roles_list)
+{
+    PMC *methods;
+    PMC *methods_iter;
+    PMC *roles_of_role;
+    PMC *proposed_add_methods;
+    int i, j, roles_count, roles_of_role_count;
+
+    /* Check we have not already composed the role; if so, just ignore it. */
+    roles_count = VTABLE_elements(interp, roles_list);
+    for (i = 0; i < roles_count; i++) {
+        if (VTABLE_get_pmc_keyed_int(interp, roles_list, i) == role)
+            return;
+    }
+
+    /* Get the methods from the role. */
+    Parrot_PCCINVOKE(interp, role, string_from_const_cstring(interp, "methods", 0),
+        "->P", &methods);
+    if (PMC_IS_NULL(methods))
+        return;
+
+    /* We need to check for conflicts before we do the composition. We
+     * put each method that would be OK to add into a proposal list, and
+     * bail out right away if we find a problem. */
+    proposed_add_methods = pmc_new(interp, enum_class_Hash);
+    methods_iter = VTABLE_get_iter(interp, methods);
+    while (VTABLE_get_bool(interp, methods_iter)) {
+        /* Get current method and its name. */
+        STRING *method_name = VTABLE_shift_string(interp, methods_iter);
+        PMC *cur_method = VTABLE_get_pmc_keyed_str(interp, methods, method_name);
+
+        /* Need to find the name we'll check for a conflict on. */
+        int excluded = 0;
+
+        /* Check if it's in the exclude list. */
+        if (got_exclude) {
+            int exclude_count = VTABLE_elements(interp, exclude);
+            for (i = 0; i < exclude_count; i++) {
+                STRING *check = VTABLE_get_string_keyed_int(interp, exclude, i);
+                if (string_equal(interp, check, method_name) == 0) {
+                    excluded = 1;
+                    break;
+                }
+            }
+        }
+
+        /* If we weren't excluded... */
+        if (!excluded) {
+            /* Is there a method with this name already in the class?
+             * XXX TODO: multi-method handling. */
+            if (VTABLE_exists_keyed_str(interp, methods_hash, method_name)) {
+                /* Conflicts with something already in the class. */
+                real_exception(interp, NULL, ROLE_COMPOSITOIN_METH_CONFLICT,
+                    "A conflict occurred during role composition due to method '%S'.",
+                    method_name);
+                return;
+            }
+
+            /* What about a conflict with ourslef? */
+            if (VTABLE_exists_keyed_str(interp, proposed_add_methods, method_name)) {
+                /* Something very weird is going on. */
+                real_exception(interp, NULL, ROLE_COMPOSITOIN_METH_CONFLICT,
+                    "A conflict occurred during role composition;"
+                    " the method '%S' from the role managed to conflict with itself somehow.",
+                    method_name);
+                return;
+            }
+
+            /* If we got here, no conflicts! Add method to the "to compose" list. */
+            VTABLE_set_pmc_keyed_str(interp, proposed_add_methods, method_name, cur_method);
+        }
+
+        /* Now see if we've got an alias. */
+        if (got_alias && VTABLE_exists_keyed_str(interp, alias, method_name)) {
+            /* Got one. Get name to alias it to. */
+            STRING *alias_name = VTABLE_get_string_keyed_str(interp, alias, method_name);
+
+            /* Is there a method with this name already in the class?
+             * XXX TODO: multi-method handling. */
+            if (VTABLE_exists_keyed_str(interp, methods_hash, alias_name)) {
+                /* Conflicts with something already in the class. */
+                real_exception(interp, NULL, ROLE_COMPOSITOIN_METH_CONFLICT,
+                    "A conflict occurred during role composition"
+                    " due to the aliasing of '%S' to '%S'.",
+                    method_name, alias_name);
+                return;
+            }
+
+            /* What about a conflict with ourslef? */
+            if (VTABLE_exists_keyed_str(interp, proposed_add_methods, alias_name)) {
+                real_exception(interp, NULL, ROLE_COMPOSITOIN_METH_CONFLICT,
+                    "A conflict occurred during role composition"
+                    " due to the aliasing of '%S' to '%S' (role already has"
+                    " a method '%S').",
+                    method_name, alias_name, alias_name);
+                return;
+            }
+
+            /* If we got here, no conflicts! Add method to the "to compose"
+             * list with its alias. */
+            VTABLE_set_pmc_keyed_str(interp, proposed_add_methods, alias_name, cur_method);
+        }
+    }
+
+    /* If we get here, we detected no conflicts. Go ahead and compose the methods. */
+    methods_iter = VTABLE_get_iter(interp, proposed_add_methods);
+    while (VTABLE_get_bool(interp, methods_iter)) {
+        /* Get current method and its name. */
+        STRING *method_name = VTABLE_shift_string(interp, methods_iter);
+        PMC *cur_method = VTABLE_get_pmc_keyed_str(interp, proposed_add_methods,
+            method_name);
+
+        /* Add it to the methods of the class. */
+        VTABLE_set_pmc_keyed_str(interp, methods_hash, method_name,
+            cur_method);
+    }
+
+    /* Add this role to the roles list. */
+    VTABLE_push_pmc(interp, roles_list, role);
+    roles_count++;
+
+    /* As a result of composing this role, we will also now do the roles
+     * that it did itself. Note that we already have the correct methods
+     * as roles "flatten" the methods they get from other roles into their
+     * own method list. */
+    Parrot_PCCINVOKE(interp, role, string_from_const_cstring(interp, "roles", 0),
+        "->P", &roles_of_role);
+    roles_of_role_count = VTABLE_elements(interp, roles_of_role);
+    for (i = 0; i < roles_of_role_count; i++) {
+        /* Only add if we don't already have it in the list. */
+        PMC *cur_role = VTABLE_get_pmc_keyed_int(interp, roles_of_role, i);
+        for (j = 0; j < roles_count; j++) {
+            if (VTABLE_get_pmc_keyed_int(interp, roles_list, j) == cur_role) {
+                /* We ain't be havin' it. */
+                VTABLE_push_pmc(interp, roles_list, cur_role);
+            }
+        }
+    }
+}
+
+
 /*
 
 =back
