@@ -2,7 +2,7 @@
 Copyright (C) 2001-2005, The Perl Foundation.
 This program is free software. It is subject to the same license as
 Parrot itself.
-$Id: /parrot/offline/src/packdump.c 4326 2007-03-08T15:36:02.208187Z coke  $
+$Id: packdump.c 18183 2007-04-14 03:15:44Z chromatic $
 
 =head1 NAME
 
@@ -28,18 +28,15 @@ This is only used by the PBC dumper C<pdump>.
 ** For now just remove some warnings
 */
 
-void PackFile_ConstTable_dump(Interp *,
-                                     struct PackFile_ConstTable *);
-static void PackFile_Constant_dump(Interp *, struct PackFile_ConstTable *ct,
-                                   struct PackFile_Constant *);
-void PackFile_Fixup_dump(Interp *,
-                         struct PackFile_FixupTable *ft);
+void PackFile_ConstTable_dump(Interp *, PackFile_ConstTable *);
+static void PackFile_Constant_dump(Interp *, PackFile_ConstTable *ct,
+                                   PackFile_Constant *);
+void PackFile_Fixup_dump(Interp *, PackFile_FixupTable *ft);
 
 /*
 
 =item C<void
-PackFile_ConstTable_dump(Interp *interp,
-                         struct PackFile_ConstTable *self)>
+PackFile_ConstTable_dump(Interp *interp, PackFile_ConstTable *self)>
 
 Dumps the constant table C<self>.
 
@@ -48,8 +45,7 @@ Dumps the constant table C<self>.
 */
 
 void
-PackFile_ConstTable_dump(Interp *interp,
-                         struct PackFile_ConstTable *self)
+PackFile_ConstTable_dump(Interp *interp, PackFile_ConstTable *self)
 {
     opcode_t i;
 
@@ -62,8 +58,8 @@ PackFile_ConstTable_dump(Interp *interp,
 /*
 
 =item C<void
-PackFile_Constant_dump(Interp *interp, struct PackFile_ConstTable *ct
-                       struct PackFile_Constant *self)>
+PackFile_Constant_dump(Interp *interp, PackFile_ConstTable *ct,
+                       PackFile_Constant *self)>
 
 Dumps the constant C<self>.
 
@@ -72,14 +68,14 @@ Dumps the constant C<self>.
 */
 
 void
-PackFile_Constant_dump(Interp *interp, struct PackFile_ConstTable *ct,
-                       struct PackFile_Constant *self)
+PackFile_Constant_dump(Interp *interp, PackFile_ConstTable *ct,
+                       PackFile_Constant *self)
 {
     struct PMC *key;
     size_t i;
     size_t ct_index;
     opcode_t slice_bits;
-    struct PackFile_Constant *detail;
+    PackFile_Constant *detail;
 
     switch (self->type) {
 
@@ -210,8 +206,7 @@ PackFile_Constant_dump(Interp *interp, struct PackFile_ConstTable *ct,
                             "\telements => %Ss,\n",
                             pmc->vtable->whoami,
                             n,
-                            out_buffer
-                            );
+                            out_buffer);
                     }
                     break;
                 case enum_class_Sub:
@@ -221,11 +216,16 @@ PackFile_Constant_dump(Interp *interp, struct PackFile_ConstTable *ct,
                         switch (sub->namespace_name->vtable->base_type) {
                             case enum_class_String:
                                 namespace_description = string_from_cstring(interp, "'", 1);
-                                namespace_description = string_append(interp, namespace_description, PMC_str_val(sub->namespace_name));
-                                namespace_description = string_append(interp, namespace_description, string_from_cstring(interp, "'", 1));
+                                namespace_description = string_append(interp,
+                                        namespace_description,
+                                        PMC_str_val(sub->namespace_name));
+                                namespace_description = string_append(interp,
+                                        namespace_description,
+                                        string_from_cstring(interp, "'", 1));
                                 break;
                             case enum_class_Key:
-                                namespace_description = key_set_to_string(interp, sub->namespace_name);
+                                namespace_description =
+                                    key_set_to_string(interp, sub->namespace_name);
                                 break;
                             default:
                                 namespace_description = sub->namespace_name->vtable->whoami;
@@ -246,19 +246,18 @@ PackFile_Constant_dump(Interp *interp, struct PackFile_ConstTable *ct,
                             sub->end_offs,
                             sub->name,
                             namespace_description,
-                            sub->HLL_id
-                            );
+                            sub->HLL_id);
                     break;
                 case enum_class_FixedIntegerArray:
                     PIO_printf(interp,
                             "\tclass => %Ss,\n"
                             "\trepr => '%Ss'\n",
                             pmc->vtable->whoami,
-                            VTABLE_get_repr(interp, pmc)
-                            );
+                            VTABLE_get_repr(interp, pmc));
                     break;
                 default:
-                    PIO_printf(interp, "\tno dump info for PMC %ld %Ss\n", pmc->vtable->base_type, pmc->vtable->whoami);
+                    PIO_printf(interp, "\tno dump info for PMC %ld %Ss\n",
+                            pmc->vtable->base_type, pmc->vtable->whoami);
                     PIO_printf(interp, "\tclass => %Ss,\n", pmc->vtable->whoami);
             }
         }
@@ -274,8 +273,7 @@ PackFile_Constant_dump(Interp *interp, struct PackFile_ConstTable *ct,
 /*
 
 =item C<void
-PackFile_Fixup_dump(Interp *interp,
-                    struct PackFile_FixupTable *ft)>
+PackFile_Fixup_dump(Interp *interp, PackFile_FixupTable *ft)>
 
 Dumps the fix-up table C<ft>.
 
@@ -284,8 +282,7 @@ Dumps the fix-up table C<ft>.
 */
 
 void
-PackFile_Fixup_dump(Interp *interp,
-                    struct PackFile_FixupTable *ft)
+PackFile_Fixup_dump(Interp *interp, PackFile_FixupTable *ft)
 {
     opcode_t i;
 
