@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2006, The Perl Foundation.
-$Id: /parrot/offline/src/pmc.c 3940 2007-02-06T15:26:21.466045Z coke  $
+$Id: pmc.c 18206 2007-04-14 20:50:06Z chromatic $
 
 =head1 NAME
 
@@ -127,7 +127,7 @@ pmc_reuse(Interp *interp, PMC *pmc, INTVAL new_type,
             /* if the PMC has a PMC_EXT structure,
              * return it to the pool/arena
              */
-            struct Small_Object_Pool * const ext_pool =
+            Small_Object_Pool * const ext_pool =
                 interp->arena_base->pmc_ext_pool;
             if (PObj_is_PMC_shared_TEST(pmc) && PMC_sync(pmc)) {
                 MUTEX_DESTROY(PMC_sync(pmc)->pmc_lock);
@@ -450,7 +450,7 @@ create_class_pmc(Interp *interp, INTVAL type)
          * return it to the pool/arena
          * we don't need it - basically only the vtable is important
          */
-        struct Small_Object_Pool * const ext_pool =
+        Small_Object_Pool * const ext_pool =
             interp->arena_base->pmc_ext_pool;
         if (PMC_sync(class))
             mem_internal_free(PMC_sync(class));
