@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2006, The Perl Foundation.
-$Id: /parrot/offline/src/pmc_freeze.c 4428 2007-03-15T03:34:11.273215Z coke  $
+$Id: pmc_freeze.c 18206 2007-04-14 20:50:06Z chromatic $
 
 =head1 NAME
 
@@ -170,7 +170,7 @@ push_ascii_string(Parrot_Interp interp, IMAGE_IO *io, STRING *s)
     UINTVAL idx = 0;
 
     /* temporary--write out in UTF-8 */
-    for ( idx = 0; idx < length; ++idx ) {
+    for (idx = 0; idx < length; ++idx) {
         *cursor++ = (unsigned char)string_index(interp, s, idx);
     }
 
@@ -196,7 +196,7 @@ static void
 push_ascii_pmc(Parrot_Interp interp, IMAGE_IO *io, const PMC* v)
 {
     char buffer[128];
-    sprintf(buffer, "%p ", v);
+    sprintf(buffer, "%p ", (const void *)v);
     str_append(interp, io->image, buffer, strlen(buffer));
 }
 
@@ -405,7 +405,7 @@ push_opcode_number(Parrot_Interp interp, IMAGE_IO *io, FLOATVAL v)
     const size_t used = s->bufused;
 
     op_check_size(interp, s, len);
-    PF_store_number( (opcode_t *)((ptrcast_t)s->strstart + used), &v);
+    PF_store_number((opcode_t *)((ptrcast_t)s->strstart + used), &v);
     s->bufused += len;
     s->strlen += len;
 }
@@ -429,7 +429,7 @@ push_opcode_string(Parrot_Interp interp, IMAGE_IO *io, STRING* v)
     const size_t used = s->bufused;
 
     op_check_size(interp, s, len);
-    PF_store_string( (opcode_t *)((ptrcast_t)s->strstart + used), v);
+    PF_store_string((opcode_t *)((ptrcast_t)s->strstart + used), v);
     s->bufused += len;
     s->strlen += len;
 }
@@ -575,8 +575,7 @@ pmc_add_ext(Parrot_Interp interp, PMC *pmc)
 /*
 
 =item C<static void
-cleanup_next_for_GC_pool(Parrot_Interp interp,
-    struct Small_Object_Pool *pool)>
+cleanup_next_for_GC_pool(Parrot_Interp interp, Small_Object_Pool *pool)>
 
 Sets all the C<next_for_GC> pointers to C<NULL>.
 
@@ -585,10 +584,9 @@ Sets all the C<next_for_GC> pointers to C<NULL>.
 */
 
 static void
-cleanup_next_for_GC_pool(Parrot_Interp interp,
-    struct Small_Object_Pool *pool)
+cleanup_next_for_GC_pool(Parrot_Interp interp, Small_Object_Pool *pool)
 {
-    struct Small_Object_Arena *arena;
+    Small_Object_Arena *arena;
 
     for (arena = pool->last_Arena; arena; arena = arena->prev) {
         PMC *p = arena->start_objects;
@@ -669,7 +667,7 @@ static void
 ft_init(Parrot_Interp interp, visit_info *info)
 {
     STRING *s = info->image;
-    struct PackFile *pf;
+    PackFile *pf;
 
     info->image_io = mem_sys_allocate(sizeof (IMAGE_IO));
     info->image_io->image = s = info->image;
@@ -810,14 +808,14 @@ thaw_pmc(Parrot_Interp interp, visit_info *info,
 
     info->extra_flags = EXTRA_IS_NULL;
     n = io->vtable->shift_pmc(interp, io);
-    if ( ((UINTVAL) n & 3) == 3) {
+    if (((UINTVAL) n & 3) == 3) {
         /* pmc has extra data */
         info->extra_flags = io->vtable->shift_integer(interp, io);
     }
-    else if ( (UINTVAL) n & 1) {     /* seen PMCs have bit 0 set */
+    else if ((UINTVAL) n & 1) {     /* seen PMCs have bit 0 set */
         seen = 1;
     }
-    else if ( (UINTVAL) n & 2) { /* prev PMC was same type */
+    else if ((UINTVAL) n & 2) { /* prev PMC was same type */
         *type = info->last_type;
     }
     else {                       /* type follows */
@@ -999,8 +997,8 @@ static UINTVAL
 id_from_pmc(Parrot_Interp interp, PMC* pmc)
 {
     UINTVAL id = 1;     /* first PMC in first arena */
-    struct Small_Object_Arena *arena;
-    struct Small_Object_Pool *pool;
+    Small_Object_Arena *arena;
+    Small_Object_Pool *pool;
     ptrdiff_t ptr_diff;
 
     pmc = (PMC*)PObj_to_ARENA(pmc);
@@ -1297,7 +1295,7 @@ visit_loop_todo_list(Parrot_Interp interp, PMC *current,
      * can't cache upper limit, visit may append items
      */
 again:
-    for (; (int)list_length(interp, todo); ) {
+    for (; (int)list_length(interp, todo);) {
         current = *(PMC**)list_shift(interp, todo, enum_type_PMC);
         VTABLE_visit(interp, current, info);
         if (thawing) {
