@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2006, The Perl Foundation.
-$Id: /parrot/offline/src/runops_cores.c 2097 2006-11-12T21:36:03.837249Z coke  $
+$Id: runops_cores.c 18206 2007-04-14 20:50:06Z chromatic $
 
 =head1 NAME
 
@@ -109,7 +109,7 @@ static opcode_t *
 runops_trace_core(Interp *interp, opcode_t *pc)
 {
     static size_t dod, gc;
-    struct Arenas *arena_base = interp->arena_base;
+    Arenas *arena_base = interp->arena_base;
     Interp *debugger;
     PMC* pio;
 
@@ -142,7 +142,7 @@ runops_trace_core(Interp *interp, opcode_t *pc)
         debugger = interp->debugger;
     trace_op(interp, code_start, code_end, pc);
     while (pc) {
-        if ( pc < code_start || pc >= code_end) {
+        if (pc < code_start || pc >= code_end) {
             internal_exception(1,
                     "attempt to access code outside of current code segment");
         }
@@ -175,7 +175,7 @@ runops_slow_core(Interp *interp, opcode_t *pc)
         return Parrot_debug(interp->debugger, pc);
     }
     while (pc) {
-        if ( pc < code_start || pc >= code_end) {
+        if (pc < code_start || pc >= code_end) {
             internal_exception(1,
                     "attempt to access code outside of current code segment");
         }
