@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2004, The Perl Foundation.
-$Id: /parrot/offline/src/stack_common.c 3225 2006-12-29T03:28:40.817280Z coke  $
+$Id: stack_common.c 18206 2007-04-14 20:50:06Z chromatic $
 
 =head1 NAME
 
@@ -84,7 +84,7 @@ Get a new chunk either from the freelist or allocate one.
 Stack_Chunk_t *cst_new_stack_chunk(Parrot_Interp interp,
                                    const Stack_Chunk_t *chunk /*NN*/)
 {
-    struct Small_Object_Pool * const pool =
+    Small_Object_Pool * const pool =
         get_bufferlike_pool(interp, chunk->size);
     Stack_Chunk_t * const new_chunk = pool->get_free_object(interp, pool);
 
