@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2006, The Perl Foundation.
-$Id: /parrot/offline/src/string.c 4375 2007-03-11T01:35:44.174089Z coke  $
+$Id: string.c 18134 2007-04-11 06:36:43Z chromatic $
 
 =head1 NAME
 
@@ -528,6 +528,7 @@ string_primary_encoding_for_representation(Interp *interp,
             return NULL;
             break;
     }
+    return NULL;
 }
 
 /*
@@ -1033,8 +1034,7 @@ string_replace(Interp *interp, STRING *src,
             offset >= 0 &&
             (UINTVAL)offset < src->strlen &&
             length == 1 &&
-            rep->strlen == 1
-            ) {
+            rep->strlen == 1) {
         if (PObj_is_cowed_TESTALL(src)) {
             Parrot_unmake_COW(interp, src);
         }
@@ -1297,7 +1297,7 @@ do { \
     restype *dp = (restype *)res->strstart; \
     size_t len = minlen; \
  \
-    for ( ; len ; ++curr1, ++curr2, ++dp, --len) \
+    for (; len ; ++curr1, ++curr2, ++dp, --len) \
         *dp = *curr1 & *curr2; \
 } while (0)
 
@@ -1389,7 +1389,7 @@ do { \
     dp = (restype *)res->strstart; \
     _index = 0; \
  \
-    for ( ; _index < maxlen ; ++curr1, ++curr2, ++dp, ++_index) { \
+    for (; _index < maxlen ; ++curr1, ++curr2, ++dp, ++_index) { \
         if (_index < length1) { \
             if (_index < length2) \
                 *dp = *curr1 op *curr2; \
@@ -1547,7 +1547,7 @@ do { \
         size_t length = s->strlen; \
         Parrot_UInt1 *dp = (Parrot_UInt1 *)res->strstart; \
  \
-        for ( ; length ; --length, ++dp, ++curr) \
+        for (; length ; --length, ++dp, ++curr) \
             *dp = 0xFF & ~ *curr; \
     } \
 } while (0)
